@@ -236,23 +236,20 @@ g_warning("DIF SUCCESS");
 #   define MAP_FAILED -1
 #endif
 
-static gboolean
+static char *
 dif_read_workbook (Workbook *book, char const *filename)
 {
-	/* TODO : When there is a reasonable error reporting
-	 * mechanism use it and put all the error code back
-	 */
-	gboolean result = FALSE;
+	char *result = NULL;
 	int len;
 	struct stat sbuf;
 	char const *data;
 	int const fd = open(filename, O_RDONLY);
 	if (fd < 0)
-		return FALSE;
+		return g_strdup (g_strerror(errno));
 
 	if (fstat(fd, &sbuf) < 0) {
 		close (fd);
-		return FALSE;
+		return g_strdup (g_strerror(errno));
 	}
 
 	len = sbuf.st_size;
@@ -269,16 +266,15 @@ dif_read_workbook (Workbook *book, char const *filename)
 		workbook_attach_sheet (book, src.sheet);
 		g_free (name);
 
-		result = dif_parse_sheet (&src);
 
-		if (!result)
-		{
-g_warning("DIF : Failed to load sheet");
+		if (!dif_parse_sheet (&src)) {
 			workbook_detach_sheet (book, src.sheet, TRUE);
+			result = g_strdup(_(("DIF : Failed to load sheet")));
 		}
 
 		munmap((char *)data, len);
-	}
+	} else
+		result = g_strdup (_("Unable to mmap the file"));
 	close(fd);
 
 	return result;
@@ -299,7 +295,7 @@ dif_write_cell (FILE *f, Cell *cell, int col, int row)
 			fputs("1,0\n\"\"\n", f);
 			break;
 
-	 	case VALUE_STRING:	/* Text Value */
+		case VALUE_STRING:	/* Text Value */
 			fputs("1,0\n\"", f);
 			fputs(cell->text->str, f);
 			fputs("\"\n", f);
@@ -346,7 +342,7 @@ dif_write_cell (FILE *f, Cell *cell, int col, int row)
 
 		}
 	}
-	
+
 	if (ferror (f))
 		return -1;
 
@@ -407,10 +403,10 @@ dif_write_workbook (Workbook *wb, const char *filename)
 			for (col = 0; col <= sheet->cols.max_used; col++) {
 				cell = sheet_cell_get (sheet, col, row);
 				rc = dif_write_cell (f, cell, col, row);
-				if (rc) 
+				if (rc)
 					goto out;
 			}
-			
+
 		}
 
 		sheet_list = sheet_list->next;
@@ -442,11 +438,14 @@ dif_cleanup_plugin (PluginData *pd)
 }
 
 
-int
-init_plugin (PluginData * pd)
+PluginInitResult
+init_plugin (CommandContext *context, PluginData * pd)
 {
 	char *desc;
-	
+
+	if (plugin_version_mismatch  (context, pd, GNUMERIC_VERSION))
+		return PLUGIN_QUIET_ERROR;
+
 	desc = _("Data Interchange Format (DIF) import");
 	file_format_register_open (1, desc, NULL, dif_read_workbook);
 
@@ -458,5 +457,5 @@ init_plugin (PluginData * pd)
 	pd->can_unload = dif_can_unload;
 	pd->cleanup_plugin = dif_cleanup_plugin;
 
-	return 0;
+	return PLUGIN_OK;
 }
