@@ -26,7 +26,7 @@ static gboolean
 excel_probe (const char *filename)
 {
 	MsOle    *file;
-	
+
 	if (ms_ole_open (&file, filename) == MS_OLE_ERR_OK) {
 		MsOleErr     result;
 		MsOleStream *stream;
@@ -47,22 +47,24 @@ excel_probe (const char *filename)
 	return FALSE;
 }
 
-static gboolean
+static char *
 excel_load (Workbook *wb, const char *filename)
 {
-	MsOle *f;
-	gboolean ret;
-	MsOleErr  result;
-	
-	result = ms_ole_open (&f, filename);
-	if (result != MS_OLE_ERR_OK) {
+	MsOleErr  ole_error;
+	MsOle	 *f;
+	char	 *workbook_error;
+
+	ole_error = ms_ole_open (&f, filename);
+	if (ole_error != MS_OLE_ERR_OK) {
 		ms_ole_destroy (&f);
-		return FALSE;
+		/* FIXME : The null string indicates using the default message
+		 * We need a more detailed message from ole_open */
+		return "";
 	}
 
 	printf ("Opening '%s' ", filename);
-	ret = ms_excel_read_workbook (wb, f);
-	if (ret) {
+	workbook_error = ms_excel_read_workbook (wb, f);
+	if (workbook_error == NULL) {
 		char *name = g_strconcat (filename, ".gnumeric", NULL);
 		ms_summary_read (f, wb->summary_info);
 
@@ -75,7 +77,7 @@ excel_load (Workbook *wb, const char *filename)
 
 	ms_ole_destroy (&f);
 
-	return ret;
+	return workbook_error;
 }
 
 
@@ -92,7 +94,7 @@ excel_save (Workbook *wb, const char *filename, eBiff_version ver)
 				 _("Saving over old files disabled for safety"));
 		return 1;
 	}
-	
+
 	result = ms_ole_create (&f, filename);
 
 	if (result != MS_OLE_ERR_OK) {
@@ -108,10 +110,7 @@ excel_save (Workbook *wb, const char *filename, eBiff_version ver)
 
 	ans = ms_excel_write_workbook (f, wb, ver);
 
-	/*
-	 * Disabled until further notice; this code breaks excel.
-	 */
-/*        ms_summary_write (f, wb->summary_info); */
+        ms_summary_write (f, wb->summary_info);
 
 	ms_ole_destroy (&f);
 
