@@ -19,7 +19,7 @@ typedef enum _eBiff_version { eBiffV2=2, eBiffV3=3,
 			      eBiffV8=8, /* Excel 97 */
 			      eBiffVUnknown=0} eBiff_version ;
 
-extern gboolean ms_excel_read_workbook  (Workbook *wb, MsOle *file);
+extern char *   ms_excel_read_workbook  (Workbook *wb, MsOle *file);
 extern int      ms_excel_write_workbook (MsOle *file, Workbook *wb,
 					 eBiff_version ver);
 
@@ -33,7 +33,7 @@ extern  EXCEL_PALETTE_ENTRY const excel_default_palette[];
 extern  char *excel_builtin_formats[];
 #define EXCEL_BUILTIN_FORMAT_LEN 0x32
 
-typedef struct 
+typedef struct
 {
 	char *prefix ;
 	int num_args ; /* -1 for multi-arg */
@@ -43,4 +43,6 @@ typedef struct
 extern FormulaFuncData formula_func_data[];
 #define FORMULA_FUNC_DATA_LEN 368
 
+#define ROW_BLOCK_MAX_LEN 32
+#define WRITEACCESS_LEN  112
 #endif
