@@ -14,6 +14,7 @@
 
 typedef struct _GnumericChartSeries
 {
+	gint dummy;
 } GnumericChartSeries;
 
 typedef struct _GnumericChart
@@ -21,7 +22,7 @@ typedef struct _GnumericChart
 	GPtrArray  *series;
 } GnumericChart;
 
-extern GnumericChart * gnumeric_chart_new ();
+extern GnumericChart * gnumeric_chart_new (void);
 extern void gnumeric_chart_destroy (GnumericChart * chart);
 
 #endif /* GNUMERIC_CHART_H */
