@@ -1,16 +1,17 @@
 /**
  * ms-ole.c: MS Office OLE support for Gnumeric
  *
- * Author:
+ * Authors:
  *    Michael Meeks (michael@imaginator.com)
  *    Arturo Tena   (arturo@directmail.org)
  **/
 
+
 /* FIXME tenix delete unused headers */
 #include <stdio.h>
 #include <unistd.h>
 #include <sys/mman.h>
-#include <sys/stat.h>
+#include <sys/stat.h>	/* for struct stat */
 #include <sys/types.h>
 #include <fcntl.h>
 #include <malloc.h>
@@ -18,15 +19,15 @@
 #include <ctype.h>
 #include <glib.h>
 
-#define  MS_OLE_H_IMPLEMENTATION
-#	include "ms-ole.h"
-#undef   MS_OLE_H_IMPLEMENTATION
+#include "ms-ole.h"
+
 
 #ifndef MAP_FAILED
 /* Someone needs their head examining - BSD ? */
 #	define MAP_FAILED ((void *)-1)
 #endif
 
+
 /* Implementational detail - not for global header */
 
 #define OLE_DEBUG 0
@@ -60,6 +61,7 @@
       B_XD_NUM  => undef,       # long 48
  */
 
+
 /**
  * Structure describing an OLE file
  **/
@@ -85,9 +87,11 @@ struct _MsOle
 };
 
 
+
 /**
  * Default system calls wrappers
  **/
+
 static int
 open2_wrap (const char *pathname, int flags)
 {
@@ -119,28 +123,28 @@ write_wrap (int fd, const void *buf, size_t count)
 }
 
 static off_t
-lseek_wrap (int fildes, off_t offset, int whence)
+lseek_wrap (int fd, off_t offset, int whence)
 {
-	return lseek (fildes, offset, whence);
+	return lseek (fd, offset, whence);
 }
 
 static int
-isregfile_wrap (int fildes)
+isregfile_wrap (int fd)
 {
 	struct stat st;
 
-	if (fstat (fildes, &st))
+	if (fstat (fd, &st))
 		return 0;
 
 	return S_ISREG(st.st_mode);
 }
 
 static int
-getfilesize_wrap (int fildes, guint32 *size)
+getfilesize_wrap (int fd, guint32 *size)
 {
 	struct stat st;
 
-	if (fstat (fildes, &st))
+	if (fstat (fd, &st))
 		return -1;
 
 	*size = st.st_size;
@@ -192,6 +196,10 @@ my_array_hack (GArray *a, guint s, guint32 idx)
 #       define ms_array_index(a,b,c) g_array_index (a, b, c)
 #endif
 
+
+typedef guint32 BLP;	/* Block pointer */
+
+
 #define BB_THRESHOLD   0x1000
 
 #define PPS_ROOT_INDEX    0
@@ -326,6 +334,7 @@ get_block_ptr (MsOle *f, BLP b, gboolean forwrite)
 	return attr->data;
 }
 
+
 /* This is a list of big blocks which contain a flat description of all blocks
    in the file. Effectively inside these blocks is a FAT of chains of other BBs,
    so the theoretical max size = 128 BB Fat blocks, thus = 128*512*512/4 blocks 
@@ -409,19 +418,17 @@ pps_get_text (guint8 *ptr, int length)
 		return 0;
 	}
 	
-	ans = (char *)g_malloc (sizeof(char) * length + 1);
+	ans = (char *) g_malloc (sizeof (char) * length + 1);
 	
-	c = MS_OLE_GET_GUINT16(ptr);
-	if (c<0x30) /* Magic unicode number I made up */
-		inb = ptr + 2;
-	else
-		inb = ptr;
-	for (lp=0;lp<length;lp++) {
-		c = MS_OLE_GET_GUINT16(inb);
-		ans[lp] = (char)c;
-		inb+=2;
+	c = MS_OLE_GET_GUINT16 (ptr);
+	inb = ptr;
+	for (lp = 0; lp < length; lp++) {
+		c = MS_OLE_GET_GUINT16 (inb);
+		ans [lp] = (char) c;
+		inb += 2;
 	}
-	ans[lp] = 0;
+	ans [lp] = 0;
+
 	return ans;
 }
 
@@ -536,18 +543,18 @@ dump_allocation (MsOle *f)
  *        default : dump header and allocation
  */
 void
-ms_ole_debug (MsOle *f, int magic)
+ms_ole_debug (MsOle *fs, int magic)
 {
 	switch (magic) {
 	case 2:
-		if (f->pps)
-			dump_tree (f->pps, 0);
+		if (fs->pps)
+			dump_tree (fs->pps, 0);
 		else
 			printf ("There are no tree (no pps)\n");
 		break;
 	default:
-		dump_header (f);
-		dump_allocation (f);
+		dump_header (fs);
+		dump_allocation (fs);
 		break;
 	}
 }
@@ -798,14 +805,13 @@ write_bb (MsOle *f)
 {
 	guint32 numbbd;
 	BLP     lp, lpblk;
+	int a = BB_BLOCK_SIZE / 4;
 
 	g_return_val_if_fail (f, 0);
 	g_return_val_if_fail (f->mem, 0);
 	g_return_val_if_fail (f->bb,  0);
 
-	numbbd  = f->bb->len/(BB_BLOCK_SIZE/4);
-	if (f->bb->len%(BB_BLOCK_SIZE/4))
-		numbbd++;
+	numbbd = (f->bb->len + a - 2) / (a - 1); /* Think really hard! */
 	SET_NUM_BBD_BLOCKS (f, numbbd);
 
 	for (lp=0;lp<numbbd;lp++) {
@@ -815,13 +821,13 @@ write_bb (MsOle *f)
 	}
 
 	lpblk = 0;
-	while (lpblk<f->bb->len) { /* Described blocks */
+	while (lpblk < f->bb->len) { /* Described blocks */
 		guint8 *mem = BB_W_PTR(f, GET_BBD_LIST(f, lpblk/(BB_BLOCK_SIZE/4)));
 		MS_OLE_SET_GUINT32 (mem + (lpblk%(BB_BLOCK_SIZE/4))*4,
 			     g_array_index (f->bb, BLP, lpblk));
 		lpblk++;
 	}
-	while (lpblk%(BB_BLOCK_SIZE/4) != 0) { /* Undescribed blocks */
+	while (lpblk % (BB_BLOCK_SIZE/4) != 0) { /* Undescribed blocks */
 		guint8 *mem;
 		g_assert (lpblk/(BB_BLOCK_SIZE/4) < numbbd);
 		mem = BB_W_PTR(f, GET_BBD_LIST(f, lpblk/(BB_BLOCK_SIZE/4)));
@@ -964,7 +970,7 @@ pps_decode_tree (MsOle *f, PPS_IDX p, PPS *parent)
 	
 #if OLE_DEBUG > 1
 	printf ("PPS decode : '%s'\n", pps->name?pps->name:"Null");
-	dump (mem, PPS_BLOCK_SIZE);
+	ms_ole_dump (mem, PPS_BLOCK_SIZE);
 #endif
 	return;
 }
@@ -1073,7 +1079,7 @@ pps_encode_tree_initial (MsOle *f, GList *list, PPS_IDX *p)
 
 #if OLE_DEBUG > 1
 	printf ("Encode '%s' as \n", pps->name);
-	dump (mem, PPS_BLOCK_SIZE);
+	ms_ole_dump (mem, PPS_BLOCK_SIZE);
 #endif
 
 	if (pps->children)
@@ -1082,101 +1088,115 @@ pps_encode_tree_initial (MsOle *f, GList *list, PPS_IDX *p)
 		pps_encode_tree_initial (f, g_list_next(list), p);
 }
 
+
 /*
  * Chain the blocks together afterwards
- * FIXME: Leaks like a sieve
  */
 static void
 pps_encode_tree_chain (MsOle *f, GList *list)
 {
-	PPS     *pps, *p;
-	GList   *l;
-	int      lp, len;
-	PPS     *next, *prev;
-	guint8  *mem, *parmem;
+	PPS	*parent;		/* parent's PPS */
+	int	len;			/* how many childrens are there */
+	GList	*lchildren;		/* visited children */
+        PPS	*children;		/* visited children's PPS */
+	PPS     *next;			/* next children's PPS */
+	PPS	*prev;			/* previous children's PPS */
+	guint8	*mem;			/* a PPS in memory */
+	guint8	*mem_parent;		/* a PPS in memory */
+	gint	i;
+	int	half_way;
 
 	g_return_if_fail (list);
 	g_return_if_fail (list->data);
-	
-	pps      = list->data;
-	parmem   = get_pps_ptr (f, pps->idx, TRUE);
-	g_return_if_fail (pps->children);
-	len      = g_list_length (pps->children);
-	l        = pps->children;
 
-	if (len == 0) {
-#if OLE_DEBUG > 0
-		printf ("Empty directory '%s'\n", pps->name);
-		return;
-#endif		
-	} else if (len == 1) {
-		p = l->data;
-		PPS_SET_DIR  (parmem, p->idx);
-		return;
-	}
-
-	g_assert (l);
-	next = prev = p = l->data;
-
-#if OLE_DEBUG > 0
-	printf ("No. of entries is %d\n", len);
-#endif
-	if (len/2==1)
-		l = g_list_next (l);
-
-	for (lp = 1; lp < len / 2; lp++) {
-		p    = l->data;
-		prev = g_list_previous(l)->data;
-
-#if OLE_DEBUG > 0
-		printf ("Chaining previous for '%s'\n", p->name);
-#endif
-		if (p->type == MsOleStorageT)
-			pps_encode_tree_chain (f, l);
-
-		mem  = get_pps_ptr (f, p->idx, TRUE);
-		PPS_SET_NEXT (mem, PPS_END_OF_CHAIN);
-		PPS_SET_PREV (mem, prev->idx);
-		l    = g_list_next (l);
-	}
-
-	g_assert (l);
-	prev   = p;
-	p      = l->data;
+	parent = list->data;
+	len = g_list_length (parent->children);
+	half_way = len / 2;
+	lchildren = parent->children;
 
 	/* The base node of the directory */
-	PPS_SET_DIR  (parmem, p->idx);
+	/* Choose the first child */
+	mem_parent = get_pps_ptr (f, parent->idx, TRUE);
 
-#if OLE_DEBUG > 0
-	printf ("Base node is '%s'\n", p->name);
+	if (len == 1) {
+		PPS_SET_DIR (mem_parent, ((PPS *)(lchildren->data))->idx);
+		/*
+		  PPS_SET_PREV (mem_parent, PPS_END_OF_CHAIN);
+		  PPS_SET_NEXT (mem_parent, PPS_END_OF_CHAIN);
+		*/
+
+#if OLE_DEBUG > 1
+		printf ("tenix3 Final encode '%s' as \n",
+			((PPS *)(parent))->name);
+		ms_ole_dump (mem_parent, PPS_BLOCK_SIZE);
+		printf ("tenix3 Final encode '%s' as \n",
+			((PPS *)(lchildren->data))->name);
+		ms_ole_dump (get_pps_ptr (f, ((PPS *)(lchildren->data))->idx, FALSE),
+		      PPS_BLOCK_SIZE);
 #endif
 
-	/* Points potentialy both ways */
-	mem    = get_pps_ptr (f, p->idx, TRUE);
-	PPS_SET_PREV (mem, prev->idx);
-	l      = g_list_next (l);
-	if (l)
-		PPS_SET_NEXT (mem, ((PPS *)l->data)->idx);
-	else
-		PPS_SET_NEXT (mem, PPS_END_OF_CHAIN);
-
-	while (l && g_list_next(l)) {
-	        p    = l->data;
-		next = g_list_next (l)->data;
-
-#if OLE_DEBUG > 0
-		printf ("Chaining next for '%s'\n", p->name);
-#endif
-		if (p->type == MsOleStorageT)
-			pps_encode_tree_chain (f, l);
-
-		mem  = get_pps_ptr (f, p->idx, TRUE);
-		PPS_SET_NEXT (mem, next->idx);
-		PPS_SET_PREV (mem, PPS_END_OF_CHAIN);
-		l = g_list_next (l);
+		return;
 	}
+
+#if OLE_DEBUG > 1
+	if (len == 0)
+		printf ("Empty directory '%s'\n", ((PPS *)(children))->name);
+#endif
+
+	i = 0;
+	for (; lchildren; lchildren = g_list_next (lchildren)) {
+		children = lchildren->data;
+
+		if (children->type == MsOleStorageT)
+			pps_encode_tree_chain (f, lchildren);
+
+		if (i == half_way)
+			PPS_SET_DIR (mem_parent, ((PPS *)(children))->idx);
+
+		mem = get_pps_ptr (f, children->idx, TRUE);
+		if (i == half_way) {
+			if (g_list_previous(lchildren)) {
+				prev = g_list_previous(lchildren)->data;
+				PPS_SET_PREV (mem, prev->idx);
+			} /* else
+				PPS_SET_PREV (mem, PPS_END_OF_CHAIN); */
+			if (g_list_next(lchildren)) {
+				next = g_list_next(lchildren)->data;
+				PPS_SET_NEXT (mem, next->idx);
+			} /* else
+				PPS_SET_NEXT (mem, PPS_END_OF_CHAIN); */
+		} else if (i < half_way) {
+			/* PPS_SET_NEXT (mem, PPS_END_OF_CHAIN); */
+			if (g_list_previous(lchildren)) {
+				prev = g_list_previous(lchildren)->data;
+				PPS_SET_PREV (mem, prev->idx);
+			} /* else
+				PPS_SET_PREV (mem, PPS_END_OF_CHAIN); */
+		} else /* i > half_way */ {
+			/* PPS_SET_PREV (mem, PPS_END_OF_CHAIN); */
+			if (g_list_next(lchildren)) {
+				next = g_list_next(lchildren)->data;
+				PPS_SET_NEXT (mem, next->idx);
+			} /* else
+				PPS_SET_NEXT (mem, PPS_END_OF_CHAIN); */
+		}
+
+#if OLE_DEBUG > 1
+			printf ("tenix1 Final encode '%s' as \n",
+				((PPS *)(children))->name);
+			ms_ole_dump (mem, PPS_BLOCK_SIZE);
+#endif
+
+		i++;
+	}
+
+#if OLE_DEBUG > 1
+	printf ("tenix2 Final encode '%s' as \n", ((PPS *)(parent))->name);
+	ms_ole_dump (mem_parent, PPS_BLOCK_SIZE);
+#endif
 }
 
+
 static int
 write_pps (MsOle *f)
 {
@@ -1409,30 +1429,46 @@ new_null_msole ()
 	return f;
 }
 
+
+/**
+ * ms_ole_ref:
+ * @fs: filesystem object.
+ * 
+ * Increment by one the count of references to the filesystem.
+ **/
 void
-ms_ole_ref (MsOle *f)
+ms_ole_ref (MsOle *fs)
 {
-	g_return_if_fail (f != NULL);
-	f->ref_count++;
+	g_return_if_fail (fs != NULL);
+	fs->ref_count++;
 }
 
+
+/**
+ * ms_ole_unref:
+ * @fs: filesystem object.
+ * 
+ * Decrement by one the count of references to the filesystem.
+ **/
 void
-ms_ole_unref (MsOle *f)
+ms_ole_unref (MsOle *fs)
 {
-	g_return_if_fail (f != NULL);
-	f->ref_count--;
+	g_return_if_fail (fs != NULL);
+	fs->ref_count--;
 }
 
+
 /**
  * ms_ole_open_vfs:
- * @f: FIXME
- * @name: name of OLE2 file to open.
- * @try_mmap: TRUE if try to mmap the OLE2 file.
- * @wrappers: system functions wrappers, NULL if standard functions are used.
+ * @fs: filesystem object.
+ * @path: path to the filesystem-in-the file on the actual filesystem.
+ * @try_mmap: TRUE if try to mmap(2) the filesystem-in-a-file,
+ *            instead of opening.
+ * @wrappers: system functions wrappers, %NULL if standard functions are used.
  * 
- * Opens a pre-existing OLE2 file, use ms_ole_create() to create a new file.
+ * Opens the filesystem-in-the-file @path and creates the filesystem object @fs.
  * 
- * Return value: a handle to the file or NULL on failure.
+ * Return value: a #MsOleErr code.
  **/
 MsOleErr
 ms_ole_open_vfs (MsOle **f, const char *name, gboolean try_mmap,
@@ -1464,13 +1500,13 @@ ms_ole_open_vfs (MsOle **f, const char *name, gboolean try_mmap,
 		g_free (*f) ;
 		return MS_OLE_ERR_EXIST;
 	}
-	if ((*f)->syswrap->getfilesize(file, &((*f)->length))) {
+	if ((*f)->syswrap->getfilesize( file, &((*f)->length) )) {
 		printf ("Couldn't get the size of file '%s'\n", name);
 		(*f)->syswrap->close (file) ;
 		g_free (*f) ;
 		return MS_OLE_ERR_EXIST;
 	}
-	if ((*f)->length<=0x4c) { /* Bad show */
+	if ((*f)->length <= 0x4c) { /* Bad show */
 #if OLE_DEBUG > 0
 		printf ("File '%s' too short\n", name);
 #endif
@@ -1538,16 +1574,18 @@ ms_ole_open_vfs (MsOle **f, const char *name, gboolean try_mmap,
 	return MS_OLE_ERR_OK;
 }
 
+
 /**
  * ms_ole_create_vfs:
- * @f: FIXME
- * @name: filename of new OLE file.
- * @try_mmap: TRUE if try to mmap the OLE2 file.
- * @wrappers: system functions wrappers, NULL if standard functions are used.
+ * @fs: filesystem object.
+ * @path: path to the filesystem-in-the file on the actual filesystem.
+ * @try_mmap: TRUE if try to mmap(2) the filesystem-in-a-file,
+ *            instead of opening.
+ * @wrappers: system functions wrappers, %NULL if standard functions are used.
  * 
- * Creates an OLE2 file: @name.
+ * Creates the filesystem-in-the-file @path and creates the filesystem @fs.
  *
- * Return value: pointer to new file or NULL on failure.
+ * Return value: a #MsOleErr code.
  **/
 MsOleErr
 ms_ole_create_vfs (MsOle **f, const char *name, gboolean try_mmap,
@@ -1567,6 +1605,7 @@ ms_ole_create_vfs (MsOle **f, const char *name, gboolean try_mmap,
 	    == -1) {
 		printf ("Can't create file '%s'\n", name);
 		g_free (*f);
+		*f = NULL;
 		return MS_OLE_ERR_PERM;
 	}
 
@@ -1576,6 +1615,7 @@ ms_ole_create_vfs (MsOle **f, const char *name, gboolean try_mmap,
 		printf ("Serious error extending file to %d bytes\n",
 			BB_BLOCK_SIZE*init_blocks);
 		g_free (*f);
+		*f = NULL;
 		return MS_OLE_ERR_SPACE;
 	}
 
@@ -1668,11 +1708,12 @@ destroy_pps (GList *l)
 	g_list_free (l);
 }
 
+
 /**
  * ms_ole_destroy:
- * @ptr: OLE2 file handle.
+ * @fs: filesystem object.
  * 
- * Closes @f and truncates any free blocks.
+ * Closes the filesystem @fs and truncates any free blocks.
  **/
 void
 ms_ole_destroy (MsOle **ptr)
@@ -1723,20 +1764,28 @@ ms_ole_destroy (MsOle **ptr)
 	*ptr = NULL;
 }
 
+
+/**
+ * ms_ole_dump:
+ * @ptr: memory area to be dumped.
+ * @len: how many bytes will be dumped.
+ * 
+ * Dump @len bytes from the memory location given by @ptr.
+ **/
 void
-dump (guint8 const *ptr, guint32 len)
+ms_ole_dump (guint8 const *ptr, guint32 len)
 {
 	guint32 lp,lp2;
 	guint32 off;
 
 	for (lp = 0;lp<(len+15)/16;lp++)
 	{
-		printf ("%8x  |  ", lp*16);
+		printf ("%8x | ", lp*16);
 		for (lp2=0;lp2<16;lp2++) {
 			off = lp2 + (lp<<4);
 			off<len?printf("%2x ", ptr[off]):printf("XX ");
 		}
-		printf ("  |  ");
+		printf ("| ");
 		for (lp2=0;lp2<16;lp2++) {
 			off = lp2 + (lp<<4);
 			printf ("%c", off<len?(ptr[off]>'!'&&ptr[off]<127?ptr[off]:'.'):'*');
@@ -1745,6 +1794,7 @@ dump (guint8 const *ptr, guint32 len)
 	}
 }
 
+
 /*
  * Redundant stream check function.
  */
@@ -1770,7 +1820,7 @@ check_stream (MsOleStream *s)
 			g_assert (g_array_index (s->blocks, BLP, idx) ==
 				  blk);
 #if OLE_DEBUG > 2
-			dump (GET_SB_R_PTR(f, blk), SB_BLOCK_SIZE);
+			ms_ole_dump (GET_SB_R_PTR(f, blk), SB_BLOCK_SIZE);
 #endif
 			blk = NEXT_SB (f, blk);
 			idx++;
@@ -1780,7 +1830,7 @@ check_stream (MsOleStream *s)
 			g_assert (g_array_index (s->blocks, BLP, idx) ==
 				  blk);
 #if OLE_DEBUG > 2
-			dump (BB_R_PTR(f, blk), BB_BLOCK_SIZE);
+			ms_ole_dump (BB_R_PTR(f, blk), BB_BLOCK_SIZE);
 #endif
 			blk = NEXT_BB (f, blk);
 			idx++;
@@ -1788,12 +1838,14 @@ check_stream (MsOleStream *s)
 	}
 }
 
+
 static MsOlePos
 tell_pos (MsOleStream *s)
 {
 	return s->position;
 }
 
+
 /*
  * Free the allocation chains, and free up the blocks.
  * "It was for freedom that Christ has set us free."
@@ -1878,9 +1930,21 @@ free_allocation (MsOle *f, guint32 startblock, gboolean is_big_block_stream)
 	}
 }
 
+
+/**
+ * ms_ole_lseek:
+ * @s: stream object.
+ * @bytes: number of bytes to set the stream pointer.
+ * @type: relative from where the stream pointer will be set.
+ * 
+ * Set the stream pointer for @s as many as @bytes bytes according to @type.
+ * 
+ * Return value: the new position of the stream pointer.
+ **/
 static MsOleSPos
 ms_ole_lseek (MsOleStream *s, MsOleSPos bytes, MsOleSeek type)
 {
+	/* FIXME tenix improve limits detection: avoid gint vs guint limits */
 	MsOleSPos newpos;
 
 	g_return_val_if_fail (s, -1);
@@ -1901,95 +1965,110 @@ ms_ole_lseek (MsOleStream *s, MsOleSPos bytes, MsOleSeek type)
 	return newpos;
 }
 
+
+/*
+ *  Returns:
+ *  NULL    - on error
+ */
 static guint8*
 ms_ole_read_ptr_bb (MsOleStream *s, MsOlePos length)
 {
-	int blockidx = s->position/BB_BLOCK_SIZE;
 	int blklen;
-	guint32 len=length;
 	guint8 *ans;
+	guint32 len=length;
+	int blockidx = s->position/BB_BLOCK_SIZE;
 
-	g_return_val_if_fail (s, 0);
+	g_return_val_if_fail (s, NULL);
 
 	if (!s->blocks || blockidx >= s->blocks->len) {
 		printf ("Reading from NULL file\n");
-		return 0;
+		return NULL;
 	}
 
 	blklen = BB_BLOCK_SIZE - s->position%BB_BLOCK_SIZE;
 
 	if (len > blklen && !s->file->ole_mmap)
-		return 0;
+		return NULL;
 
 	while (len > blklen) {
 		len -= blklen;
 		blklen = BB_BLOCK_SIZE;
-		if (blockidx >= (s->blocks->len - 1) ||
-		    (ms_array_index (s->blocks, BLP, blockidx) !=
-		     blockidx + 1))
-			return 0;
+		if (blockidx >= (s->blocks->len - 1)
+		    || (ms_array_index (s->blocks, BLP, blockidx)
+			!= blockidx + 1))
+			return NULL;
 		blockidx++;
 	}
 	/* Straight map, simply return a pointer */
-	ans = BB_R_PTR(s->file, ms_array_index (s->blocks, BLP, s->position/BB_BLOCK_SIZE))
-	      + s->position%BB_BLOCK_SIZE;
+	ans = BB_R_PTR (s->file, ms_array_index (s->blocks, BLP,
+						 s->position/BB_BLOCK_SIZE))
+		+ s->position%BB_BLOCK_SIZE;
 	ms_ole_lseek (s, length, MsOleSeekCur);
+
 	if (libole2_debug)
 		check_stream (s);
 
 	return ans;
 }
 
+
+/*
+ *  Returns:
+ *  NULL    - on error
+ */
 static guint8*
 ms_ole_read_ptr_sb (MsOleStream *s, MsOlePos length)
 {
-	int blockidx = s->position/SB_BLOCK_SIZE;
 	int blklen;
-	guint32 len=length;
 	guint8 *ans;
+	guint32 len=length;
+	int blockidx = s->position/SB_BLOCK_SIZE;
 
-	g_return_val_if_fail (s, 0);
+	g_return_val_if_fail (s, NULL);
 
 	if (!s->blocks || blockidx >= s->blocks->len) {
 		printf ("Reading from NULL file\n");
-		return 0;
+		return NULL;
 	}
 
 	blklen = SB_BLOCK_SIZE - s->position%SB_BLOCK_SIZE;
 
 	if (len > blklen && !s->file->ole_mmap)
-		return 0;
+		return NULL;
 
 	while (len > blklen) {
 		len -= blklen;
 		blklen = SB_BLOCK_SIZE;
-		if (blockidx >= (s->blocks->len - 1) ||
-		    (ms_array_index (s->blocks, BLP, blockidx) !=
-		     blockidx + 1))
-			return 0;
+		if (blockidx >= (s->blocks->len - 1)
+		    || (ms_array_index (s->blocks, BLP, blockidx)
+			!= blockidx + 1))
+			return NULL;
 		blockidx++;
 	}
 	/* Straight map, simply return a pointer */
-	ans = GET_SB_R_PTR(s->file, ms_array_index (s->blocks, BLP, s->position/SB_BLOCK_SIZE))
+	ans = GET_SB_R_PTR (s->file, ms_array_index (s->blocks, BLP,
+						     s->position/SB_BLOCK_SIZE))
 		+ s->position%SB_BLOCK_SIZE;
 	ms_ole_lseek (s, length, MsOleSeekCur);
+
 	if (libole2_debug)
 		check_stream (s);
 
 	return ans;
 }
 
+
 /*
  *  Returns:
- *  0 - on error
- *  1 - on success
+ *  zero    - on error
+ *  no zero - on success
  */
-static MsOlePos
+static gint
 ms_ole_read_copy_bb (MsOleStream *s, guint8 *ptr, MsOlePos length)
 {
-	int offset = s->position%BB_BLOCK_SIZE;
-	int blkidx = s->position/BB_BLOCK_SIZE;
 	guint8 *src;
+	int offset = s->position % BB_BLOCK_SIZE;
+	int blkidx = s->position / BB_BLOCK_SIZE;
 
 	g_return_val_if_fail (s, 0);
 	g_return_val_if_fail (ptr, 0);
@@ -1999,15 +2078,15 @@ ms_ole_read_copy_bb (MsOleStream *s, guint8 *ptr, MsOlePos length)
 		return 0;
 	}
 
-	while (length>0)
+	while (length > 0)
 	{
 		BLP block;
 		int cpylen = BB_BLOCK_SIZE - offset;
-		if (cpylen>length)
+		if (cpylen > length)
 			cpylen = length;
 
-		if (s->position + cpylen > s->size ||
-		    blkidx == s->blocks->len) {
+		if (s->position + cpylen > s->size
+		    || blkidx == s->blocks->len) {
 #if OLE_DEBUG > 0
 			printf ("Trying 2 to read beyond end of stream %d+%d %d\n",
 				s->position, cpylen, s->size);
@@ -2016,7 +2095,7 @@ ms_ole_read_copy_bb (MsOleStream *s, guint8 *ptr, MsOlePos length)
 		}
 		g_assert (blkidx < s->blocks->len);
 		block = ms_array_index (s->blocks, BLP, blkidx);
-		src = BB_R_PTR(s->file, block) + offset;
+		src = BB_R_PTR (s->file, block) + offset;
 		
 		memcpy (ptr, src, cpylen);
 		ptr    += cpylen;
@@ -2027,12 +2106,20 @@ ms_ole_read_copy_bb (MsOleStream *s, guint8 *ptr, MsOlePos length)
 		blkidx++;
 		s->position+=cpylen;
 	}
+
 	if (libole2_debug)
 		check_stream (s);
+
 	return 1;
 }
 
-static MsOlePos
+
+/*
+ *  Returns:
+ *  zero    - on error
+ *  no zero - on success
+ */
+static gint
 ms_ole_read_copy_sb (MsOleStream *s, guint8 *ptr, MsOlePos length)
 {
 	int offset = s->position%SB_BLOCK_SIZE;
@@ -2047,14 +2134,14 @@ ms_ole_read_copy_sb (MsOleStream *s, guint8 *ptr, MsOlePos length)
 		return 0;
 	}
 
-	while (length>0)
+	while (length > 0)
 	{
 		int cpylen = SB_BLOCK_SIZE - offset;
 		BLP block;
 		if (cpylen>length)
 			cpylen = length;
-		if (s->position + cpylen > s->size ||
-		    blkidx == s->blocks->len) {
+		if (s->position + cpylen > s->size
+		    || blkidx == s->blocks->len) {
 #if OLE_DEBUG > 0
 			printf ("Trying 3 to read beyond end of stream %d+%d %d\n",
 				s->position, cpylen, s->size);
@@ -2066,7 +2153,7 @@ ms_ole_read_copy_sb (MsOleStream *s, guint8 *ptr, MsOlePos length)
 		src = GET_SB_R_PTR(s->file, block) + offset;
 				
 		memcpy (ptr, src, cpylen);
-		ptr   += cpylen;
+		ptr += cpylen;
 		length -= cpylen;
 		
 		offset = 0;
@@ -2074,11 +2161,14 @@ ms_ole_read_copy_sb (MsOleStream *s, guint8 *ptr, MsOlePos length)
 		blkidx++;
 		s->position+=cpylen;
 	}
+
 	if (libole2_debug)
 		check_stream (s);
+
 	return 1;
 }
 
+
 static void
 ms_ole_append_block (MsOleStream *s)
 {
@@ -2144,21 +2234,21 @@ ms_ole_append_block (MsOleStream *s)
 	}
 }
 
+
 /* FIXME: I'm sure these functions should fail gracefully somehow :-) */
 static MsOlePos
 ms_ole_write_bb (MsOleStream *s, guint8 *ptr, MsOlePos length)
 {
-	guint8 *dest;
-	int     offset  = s->position%BB_BLOCK_SIZE;
-	guint32 blkidx  = s->position/BB_BLOCK_SIZE;
-	guint32 bytes   = length;
-	gint32  lengthen;
+	guint8  *dest;
+	gint32   lengthen;
+	guint32  bytes   = length;
+	int      offset  = s->position%BB_BLOCK_SIZE;
+	guint32  blkidx  = s->position/BB_BLOCK_SIZE;
 	
 	s->file->dirty = 1;
 	while (bytes > 0) {
 		BLP block;
 		int cpylen = BB_BLOCK_SIZE - offset;
-
 		if (cpylen > bytes)
 			cpylen = bytes;
 		
@@ -2193,6 +2283,8 @@ ms_ole_write_bb (MsOleStream *s, guint8 *ptr, MsOlePos length)
 	return length;
 }
 
+
+/* FIXME: I'm sure these functions should fail gracefully somehow :-) */
 static MsOlePos
 ms_ole_write_sb (MsOleStream *s, guint8 *ptr, MsOlePos length)
 {
@@ -2287,6 +2379,7 @@ ms_ole_write_sb (MsOleStream *s, guint8 *ptr, MsOlePos length)
 
 /**
  * pps_create:
+ * @f: ole file handle.
  * @p: returned pps.
  * @parent: parent pps.
  * @name: its name.
@@ -2297,7 +2390,8 @@ ms_ole_write_sb (MsOleStream *s, guint8 *ptr, MsOlePos length)
  * Return value: error status.
  **/
 static MsOleErr
-pps_create (GList **p, GList *parent, const char *name, MsOleType type)
+pps_create (MsOle *f, GList **p, GList *parent, const char *name,
+	    MsOleType type)
 {
 	PPS *pps, *par;
 
@@ -2322,6 +2416,7 @@ pps_create (GList **p, GList *parent, const char *name, MsOleType type)
 	par->children = g_list_insert_sorted (par->children, pps,
 					      (GCompareFunc)pps_compare_func);
 	*p = g_list_find (par->children, pps);
+	f->num_pps++;
 
 	return MS_OLE_ERR_OK;
 }
@@ -2334,8 +2429,7 @@ pps_create (GList **p, GList *parent, const char *name, MsOleType type)
  * Find the right Stream ... John 4:13-14 ...
  * in a storage
  * 
- * Return value: NULL if not found or pointer
- * to the child list
+ * Return value: %NULL if not found or pointer to the child list
  **/
 static GList *
 find_in_pps (GList *l, const char *name)
@@ -2373,15 +2467,15 @@ find_in_pps (GList *l, const char *name)
 
 /**
  * path_to_pps:
- * @pps:  pointer to pps to return value in
- * @f:    ole file hande
- * @path: path to find
- * @file: file to find in path
- * @create_if_not_found: :-)
+ * @pps:  pointer to pps to return value in.
+ * @f:    ole file hande.
+ * @path: path to find.
+ * @file: file to find in path.
+ * @create_if_not_found: create the pps with the given path if not found.
  * 
- * Locates a stream or storage with the given path
+ * Locates a stream or storage with the given path.
  * 
- * Return value: error status
+ * Return value: a #MsOleErr code.
  **/
 static MsOleErr
 path_to_pps (PPS **pps, MsOle *f, const char *path,
@@ -2411,7 +2505,7 @@ path_to_pps (PPS **pps, MsOle *f, const char *path,
 		cur = find_in_pps (parent, dirs[lp]);
 		
 		if (!cur && create_if_not_found &&
-		    pps_create (&cur, parent, dirs[lp], MsOleStorageT) !=
+		    pps_create (f, &cur, parent, dirs[lp], MsOleStorageT) !=
 		    MS_OLE_ERR_OK)
 			cur = NULL;
 		/* else carry on not finding them before dropping out */
@@ -2436,7 +2530,8 @@ path_to_pps (PPS **pps, MsOle *f, const char *path,
 	if (!cur) {
 		if (create_if_not_found) {
 			MsOleErr result;
-			result = pps_create (&cur, parent, file, MsOleStreamT);
+			result = pps_create (f, &cur, parent, file,
+					     MsOleStreamT);
 			if (result == MS_OLE_ERR_OK) {
 				*pps = cur->data;
 				g_return_val_if_fail (IS_PPS (cur->data),
@@ -2457,13 +2552,36 @@ path_to_pps (PPS **pps, MsOle *f, const char *path,
 	return MS_OLE_ERR_EXIST;
 }
 
+
+/**
+ * ms_ole_unlink:
+ * @fs: filesystem object.
+ * @path: path of the stream or directory to delete.
+ *
+ * Delete the stream or directory @path on the filesystem @fs.
+ *
+ * Return value: a #MsOleErr code.
+ **/
 MsOleErr
 ms_ole_unlink (MsOle *f, const char *path)
 {
 	g_warning ("Unimplemented");
+
+	/* FIXME missing implementation, or at least a better error code =-) */
 	return MS_OLE_ERR_NOTEMPTY;
 }
 
+
+/**
+ * ms_ole_directory:
+ * @names: array where the names are storesd, it's %NULL ended.
+ * @fs: filesystem object.
+ * @dirpath: directory path.
+ *
+ * Gets the names of the streams and directories in the directory @dirpath.
+ *
+ * Returns: a #MsOleErr code.
+ **/
 MsOleErr
 ms_ole_directory (char ***names, MsOle *f, const char *path)
 {
@@ -2502,6 +2620,19 @@ ms_ole_directory (char ***names, MsOle *f, const char *path)
 	return MS_OLE_ERR_OK;
 }
 
+
+/**
+ * ms_ole_stat:
+ * @stat: stat information.
+ * @fs: filesystem object.
+ * @dirpath: directory path.
+ * @name: stream or directory name.
+ *
+ * Gets information about the stream or the directory which is in the directory
+ * @dirpath and its name is @file.
+ *
+ * Returns: a #MsOleErr code.
+ **/
 MsOleErr
 ms_ole_stat (MsOleStat *stat, MsOle *f, const char *path,
 	     const char *file)
@@ -2530,15 +2661,17 @@ ms_ole_stat (MsOleStat *stat, MsOle *f, const char *path,
 
 /**
  * ms_ole_stream_open:
- * @stream: FIXME
- * @f: FIXME
- * @path: FIXME
- * @fname: FIXME
+ * @stream: stream object.
+ * @fs: filesystem object.
+ * @dirpath: directory of the stream.
+ * @name: stream name.
  * @mode: mode of opening stream.
  * 
- * @mode is 'r' for read only or 'w' for write only.
- * 
- * Return value: handle to an stream.
+ * Opens the stream in @dirpath with the name @name and creates the stream
+ * object @stream. If @mode is '%r' it opens read only, and if it is '%w'
+ * it opens for write only.
+ *
+ * Return value: a #MsOleErr code.
  **/
 MsOleErr
 ms_ole_stream_open (MsOleStream ** const stream, MsOle *f,
@@ -2683,13 +2816,15 @@ ms_ole_stream_open (MsOleStream ** const stream, MsOle *f,
 	return MS_OLE_ERR_OK;
 }
 
+
 /**
- * ms_ole_stream_copy:
- * @s: stream to be copied
+ * ms_ole_stream_duplicate:
+ * @stream_copy: stream object copy.
+ * @stream: stream object to be duplicated.
  * 
- * Duplicates stream _handle_ @s
+ * Duplicates the stream object @stream.
  * 
- * Return value: copy of @s
+ * Return value: a #MsOleErr code.
  **/
 MsOleErr
 ms_ole_stream_duplicate (MsOleStream **s, const MsOleStream * const stream)
@@ -2709,13 +2844,14 @@ ms_ole_stream_duplicate (MsOleStream **s, const MsOleStream * const stream)
 	return MS_OLE_ERR_OK;
 }
 
+
 /**
  * ms_ole_stream_close:
- * @s: stream handle
+ * @stream: stream object to be closed.
  * 
- * Closes stream @s and de-allocates resources.
+ * Closes the @stream.
  * 
- * Return value: FIXME
+ * Return value: a #MsOleErr code.
  **/
 MsOleErr
 ms_ole_stream_close (MsOleStream **s)
