@@ -12,7 +12,12 @@
 #include "ms-ole.h"
 #include "ms-biff.h"
 #include "ms-excel-biff.h"
+#include "ms-excel-util.h"
 
+typedef struct _ExcelFont     ExcelFont;
+typedef struct _ExcelCell     ExcelCell;
+typedef struct _ExcelRow      ExcelRow;
+typedef struct _ExcelCol      ExcelCol;
 typedef struct _ExcelSheet    ExcelSheet;
 typedef struct _ExcelWorkbook ExcelWorkbook;
 typedef struct _XF       XF;
@@ -20,20 +25,41 @@ typedef struct _Fonts    Fonts;
 typedef struct _Formats  Formats;
 typedef struct _Palette  Palette;
 
+struct _ExcelFont {
+	StyleFont  *style_font;
+	guint32    color;
+};
+
 struct _Palette {
-	GHashTable *col_to_idx;
+	TwoWayTable *two_way_table;
+	guint8 entry_in_use[EXCEL_DEF_PAL_LEN];
 };
 
 struct _Fonts {
-	GHashTable *StyleFont_to_idx;
+	TwoWayTable *two_way_table;
 };
 
 struct _Formats {
-	GHashTable *StyleFormat_to_idx;
+	TwoWayTable *two_way_table;
 };
 
 struct _XF {
-	GHashTable *Style_to_idx;
+	TwoWayTable *two_way_table;
+	MStyle      *default_style;
+};
+
+struct _ExcelCell {
+	gint     xf;
+	Cell    *gnum_cell;
+};
+
+struct _ExcelCol
+{
+	ExcelSheet *sheet;
+	guint16 first;
+	guint16 last;
+	double  width;
+	guint16 xf;
 };
 
 struct _ExcelSheet {
@@ -45,12 +71,16 @@ struct _ExcelSheet {
 	guint32        maxx;
 	guint32        maxy;
 	GHashTable    *formula_cache;
+	gpointer       cell_used_map;
+	ExcelCell     *cells;
+	double         base_char_width;
 };
 
 struct _ExcelWorkbook {
 	Workbook      *gnum_wb;
 	GPtrArray     *sheets;
 	eBiff_version  ver;
+	XF            *xf;
 	Palette       *pal;
 	Fonts         *fonts;
 	Formats       *formats;
@@ -58,24 +88,35 @@ struct _ExcelWorkbook {
 	MsOlePos   streamPos;
 };
 
-extern int ms_excel_write_ExcelWorkbook (MsOle *file, ExcelWorkbook *wb,
-				    eBiff_version ver);
-extern int ms_excel_write_get_sheet_idx (ExcelWorkbook *wb, Sheet *gnum_sheet);
-extern int ms_excel_write_get_externsheet_idx (ExcelWorkbook *wb,
-					       Sheet *gnum_sheeta,
-					       Sheet *gnum_sheetb);
-
 typedef enum {
 	AS_PER_VER,  /* Biff7: byte length, UTF8, Biff8: word length, unicode */
 	SIXTEEN_BIT, /* word length, Biff7: UTF8, Biff8: unicode */
 	EIGHT_BIT    /* byte length, Biff7: UTF8, Biff8: unicode */
 } PutType;
 
+#define XF_RESERVED 21
+#define XF_MAGIC 0
+#define FONTS_MINIMUM 5
+#define FONT_SKIP 4
+#define FONT_MAGIC 0
+#define FORMAT_MAGIC 0
+#define PALETTE_BLACK 0
+#define PALETTE_ALSO_BLACK 8
+#define PALETTE_WHITE 1
+#define FILL_MAGIC 0
+#define BORDER_MAGIC STYLE_BORDER_NONE
+
 extern int
 biff_put_text (BiffPut *bp, const char *txt, eBiff_version ver,
 	       gboolean write_len, PutType how);
-
+extern int ms_excel_write_ExcelWorkbook (MsOle *file, ExcelWorkbook *wb,
+				          eBiff_version ver);
+extern int ms_excel_write_get_sheet_idx (ExcelWorkbook *wb, Sheet *gnum_sheet);
+extern int ms_excel_write_get_externsheet_idx (ExcelWorkbook *wb,
+					       Sheet *gnum_sheeta,
+					       Sheet *gnum_sheetb);
 extern int
 ms_excel_write_map_errcode (Value const * const v);
 
+extern int ms_excel_write_debug;
 #endif
