@@ -4,7 +4,7 @@
  *
  * Vincent Renardias <vincent@ldsol.com>
  *
- * $Id: csv-io.h,v 1.2 1999/06/15 15:12:37 mortenw Exp $
+ * $Id: csv-io.h,v 1.5 1999/12/30 09:11:55 unammx Exp $
  */
 
 #ifndef GNUMERIC_CSV_IO_H
@@ -13,6 +13,6 @@
 #include "sheet.h"
 #include "plugin.h"
 
-int       init_plugin (PluginData *pd);
+PluginInitResult       init_plugin (CommandContext *context, PluginData *pd);
 
 #endif /* GNUMERIC_CSV_IO_H */
