@@ -93,13 +93,18 @@ html_init (void)
 /*
  * called by gnumeric to load the plugin
  */
-int
-init_plugin (PluginData *pd)
+PluginInitResult
+init_plugin (CommandContext *context, PluginData *pd)
 {
+	if (plugin_version_mismatch  (context, pd, GNUMERIC_VERSION))
+		return PLUGIN_QUIET_ERROR;
+
 	html_init ();
+
 	pd->can_unload = html_can_unload;
 	pd->cleanup_plugin = html_cleanup_plugin;
 	pd->title = g_strdup (_("HTML (simple html export/import plugin)"));
-	return 0;
+
+	return PLUGIN_OK;
 }
 
