@@ -24,6 +24,8 @@
 
 #include "../../src/gnumeric.h"
 #include "../../src/gnumeric-util.h"
+#include "../../src/sheet-object.h"
+#include "../../src/sheet-object-graphic.h"
 
 int epsf_write_wb (Workbook *wb, const char *filename);
 
