@@ -27,7 +27,7 @@
 
 int html_write_wb_html32 (Workbook *wb, const char *filename);
 int html_write_wb_html40 (Workbook *wb, const char *filename);
-gboolean html_read (Workbook *wb, const char *filename);
+char *html_read (Workbook *wb, const char *filename);
 
 #define G_PLUGIN_FOR_HTML "GPFH/0.5"
 
