@@ -51,15 +51,15 @@ lotus_probe (const char *filename)
 }
 
 
-static gboolean
+static char *
 lotus_load (Workbook *wb, const char *filename)
 {
 	char *name, *p;
-	gboolean ret;
-	
+	char * ret;
+
 	ret = lotus_read (wb, filename);
 
-	if (ret) {
+	if (ret == NULL) {
 		if ((p = filename_ext (filename)) != NULL)
 			*p = '\0'; /* remove "wk1" */
 		name = g_strconcat (p, "gnumeric", NULL);
@@ -83,16 +83,19 @@ lotus_cleanup_plugin (PluginData *pd)
 	g_free (pd->title);
 }
 
-int
-init_plugin (PluginData *pd)
+PluginInitResult
+init_plugin (CommandContext *context, PluginData *pd)
 {
 	char *descr  = _("Lotus (*.wk1) file format");
 
+	if (plugin_version_mismatch  (context, pd, GNUMERIC_VERSION))
+		return PLUGIN_QUIET_ERROR;
+
 	file_format_register_open (50, descr, lotus_probe, lotus_load);
 
 	pd->can_unload     = lotus_can_unload;
 	pd->cleanup_plugin = lotus_cleanup_plugin;
 	pd->title = g_strdup (_("Lotus 123 file import/export plugin"));
 
-	return 0;
+	return PLUGIN_OK;
 }
