@@ -20,20 +20,20 @@ static PyObject *
 convert_value_to_python (Value *v)
 {
 	PyObject *o;
-	
+
 	switch (v->type) {
 	case VALUE_INTEGER:
 		o = PyInt_FromLong(v->v.v_int);
 		break;
-		
+
 	case VALUE_FLOAT:
 		o = PyFloat_FromDouble(v->v.v_float);
 		break;
-		
+
 	case VALUE_STRING:
 		o = PyString_FromString(v->v.str->str);
 		break;
-		
+
 	default:
 		o = NULL;
 		break;
@@ -45,10 +45,10 @@ static Value *
 convert_python_to_value (PyObject *o)
 {
 	Value *v = g_new (Value, 1);
-	
+
 	if (!v)
 		return NULL;
-	
+
 	if (PyInt_Check (o)){
 		v->type = VALUE_INTEGER;
 		v->v.v_int = (int_t) PyInt_AsLong (o);
@@ -58,7 +58,7 @@ convert_python_to_value (PyObject *o)
 	} else if (PyString_Check (o)) {
 		int size = PyString_Size (o);
 		gchar *s;
-		
+
 		s = g_malloc (size + 1);
 		strncpy(s, PyString_AsString (o), size);
 		s[size] = '\0';
@@ -69,7 +69,7 @@ convert_python_to_value (PyObject *o)
 		g_free (v);
 		return NULL;
 	}
-	
+
 	return v;
 }
 
@@ -87,26 +87,28 @@ fndef_compare(FuncData *fdata, FunctionDefinition *fndef)
 }
 
 static Value *
-marshal_func (FunctionEvalInfo *ei, Value *argv[])
+marshal_func (FunctionEvalInfo *ei, Value *argv [])
 {
 	PyObject *args, *result;
 	FunctionDefinition *fndef = ei->func_def;
 	Value *v;
 	GList *l;
-	int i, count = strlen(fndef->args);
-	
+	int i, min, max;
+
+	function_def_count_args (fndef, &min, &max);
+
 	/* Find the Python code object for this FunctionDefinition. */
-	l = g_list_find_custom(funclist, fndef, (GCompareFunc) fndef_compare);
+	l = g_list_find_custom (funclist, fndef, (GCompareFunc) fndef_compare);
 	if (!l)
 		return value_new_error (&ei->pos, _("Unable to lookup Python code object."));
-	
+
 	/* Build the argument list which is a Python tuple. */
-	args = PyTuple_New (count);
-	for (i = 0; i < count; i++){
+	args = PyTuple_New (min);
+	for (i = 0; i < min; i++) {
 		/* ref is stolen from us */
-		PyTuple_SetItem(args, i, convert_value_to_python (argv[i]));  
+		PyTuple_SetItem (args, i, convert_value_to_python (argv [i]));
 	}
-	
+
 	/* Call the Python object. */
 	result = PyEval_CallObject (((FuncData *)(l->data))->codeobj, args);
 	Py_DECREF (args);
@@ -115,7 +117,7 @@ marshal_func (FunctionEvalInfo *ei, Value *argv[])
 		PyErr_Clear (); /* XXX should popup window with exception info */
 		return value_new_error (&ei->pos, _("Python exception."));
 	}
-	
+
 	v = convert_python_to_value (result);
 	Py_DECREF (result);
 	return v;
@@ -132,30 +134,24 @@ __register_function (PyObject *m, PyObject *py_args)
 
 	if (!PyArg_ParseTuple (py_args, "ssssO", &name, &args, &named_args, &help1, &codeobj))
 		return NULL;
-	
+
 	if (!PyCallable_Check (codeobj)){
 		PyErr_SetString (PyExc_TypeError, _("object must be callable"));
 		return NULL;
 	}
-	
-	fndef = g_new0 (FunctionDefinition, 1);
-	if (!fndef){
-		PyErr_SetString (PyExc_MemoryError, _("could not alloc FuncDef"));
-		return NULL;
-	}
 
 	cat   = function_get_category (_("Perl"));
 	help  = g_new (char *, 1);
 	*help = g_strdup (help1);
 	fndef = function_add_args (cat, g_strdup (name), g_strdup (args),
 				   g_strdup (named_args), help, marshal_func);
-	
+
 	fdata = g_new (FuncData, 1);
-	fdata->fndef = fndef;
+	fdata->fndef   = fndef;
 	fdata->codeobj = codeobj;
 	Py_INCREF(codeobj);
 	funclist = g_list_append(funclist, fdata);
-	
+
 	Py_INCREF (Py_None);
 	return Py_None;
 }
@@ -171,7 +167,7 @@ initgnumeric(void)
 	PyImport_AddModule ("gnumeric");
 	Py_InitModule ("gnumeric", gnumeric_funcs);
 	g_print (_("Gnumeric/Python module initialized\n"));
-}  
+}
 
 static int
 no_unloading_for_me (PluginData *pd)
@@ -179,32 +175,38 @@ no_unloading_for_me (PluginData *pd)
 	return 0;
 }
 
-int
-init_plugin (PluginData * pd)
+PluginInitResult
+init_plugin (CommandContext *context, PluginData * pd)
 {
+	if (plugin_version_mismatch  (context, pd, GNUMERIC_VERSION))
+		return PLUGIN_QUIET_ERROR;
+
 	pd->can_unload = no_unloading_for_me;
 	pd->title = g_strdup (_("Python Plugin"));
-	
-	
+
 	/* initialize the python interpreter */
 	Py_SetProgramName ("gnumeric");
 	Py_Initialize ();
-	
+
 	/* setup standard functions */
 	initgnumeric ();
 	if (PyErr_Occurred ()) {
+		/* FIXME : If I knew how to get the string representation of the
+		 * error I'd use gnumeric_error_plugin_problem()
+		 * We need a maintainer for this code that knows python.
+		 */
 		PyErr_Print ();
-		return -1;
+		return PLUGIN_ERROR;
 	}
-	
+
 	/* plugin stuff */
-	
+
 	/* run the magic python file */
-	
+
 	{
 		char *name;
 		FILE *fp;
-		
+
 		name = gnome_unconditional_datadir_file ("gnumeric/python/gnumeric_startup.py");
 		fp = fopen (name, "r");
 		if (fp){
@@ -212,6 +214,6 @@ init_plugin (PluginData * pd)
 		}
 		g_free(name);
 	}
-	
-	return 0;
+
+	return PLUGIN_OK;
 }
