@@ -5,7 +5,7 @@
  *
  * Takashi Matsuda <matsu@arch.comp.kyutech.ac.jp>
  *
- * $Id: text-io.h,v 1.1 1999/03/10 02:00:04 unammx Exp $
+ * $Id: text-io.h,v 1.4 1999/12/30 09:12:00 unammx Exp $
  */
 
 #ifndef GNUMERIC_TEXT_IO_H
@@ -15,6 +15,6 @@
 #include "../../src/gnumeric-util.h"
 #include "../../src/plugin.h"
 
-int       init_plugin (PluginData *pd);
+PluginInitResult       init_plugin (CommandContext *context, PluginData *pd);
 
 #endif /* GNUMERIC_TEXT_IO_H */
