@@ -134,7 +134,7 @@ xbase_field_as_value (XBrecord *record, guint num)
 	}
 }
 
-static gboolean
+static char *
 xbase_load (Workbook *wb, const char *filename)
 {
 	XBfile *file;
@@ -144,9 +144,9 @@ xbase_load (Workbook *wb, const char *filename)
 	Sheet    *sheet = NULL;
 	Cell *cell;
 	Value *val;
-	
+
 	if ((file = xbase_open (filename)) == NULL)
-		return FALSE;
+		return "";
 
 	if ((p = filename_ext (name)) != NULL)
 		*p = '\0'; /* remove "dbf" */
@@ -161,7 +161,7 @@ xbase_load (Workbook *wb, const char *filename)
 	g_free (name);
 
 	cell_deep_freeze_redraws ();
-	
+
 	field = 0;
 	while (field < file->fields) {
 		cell = sheet_cell_fetch (sheet, field, 0);
@@ -175,7 +175,7 @@ xbase_load (Workbook *wb, const char *filename)
 		while (field < file->fields) {
 			cell = sheet_cell_fetch (sheet, field, row);
 			cell_set_value_simple (cell, val =
-					       xbase_field_as_value 
+					       xbase_field_as_value
 					       (rec, ++field));
 		}
 		row++;
@@ -185,8 +185,8 @@ xbase_load (Workbook *wb, const char *filename)
 	cell_deep_thaw_redraws ();
 
 	xbase_close (file);
-	
-	return TRUE;
+
+	return NULL;
 }
 
 static int
@@ -202,11 +202,14 @@ xbase_cleanup_plugin (PluginData *pd)
 	g_free (pd->title);
 }
 
-int
-init_plugin (PluginData *pd)
+PluginInitResult
+init_plugin (CommandContext *context, PluginData *pd)
 {
 	char *descr  = _("Xbase (*.dbf) file format");
 
+	if (plugin_version_mismatch  (context, pd, GNUMERIC_VERSION))
+		return PLUGIN_QUIET_ERROR;
+
 	/* We register XBase format with a precendence of 100 */
 	file_format_register_open (100, descr, xbase_probe, xbase_load);
 
@@ -214,5 +217,5 @@ init_plugin (PluginData *pd)
 	pd->cleanup_plugin = xbase_cleanup_plugin;
 	pd->title = g_strdup (_("XBase file import/export plugin"));
 
-	return 0;
+	return PLUGIN_OK;
 }
