@@ -48,12 +48,20 @@ application_clipboard_clear (void)
 	}
 	if (app.clipboard_sheet != NULL) {
 		Sheet *sheet = app.clipboard_sheet;
+
 		sheet_selection_unant (sheet);
-		workbook_view_set_paste_state (sheet->workbook, 0);
+		workbook_view_set_paste_special_state (sheet->workbook, FALSE);
 		app.clipboard_sheet = NULL;
 	}
 }
 
+void
+application_clipboard_unant (void)
+{
+	if (app.clipboard_sheet != NULL)
+		sheet_selection_unant (app.clipboard_sheet);
+}
+
 /**
  * application_clipboard_copy:
  *
@@ -75,7 +83,7 @@ application_clipboard_copy (Sheet *sheet, Range const *area)
 				       area->start.col, area->start.row,
 				       area->end.col,   area->end.row);
 
-	workbook_view_set_paste_state (sheet->workbook, 2);
+	workbook_view_set_paste_special_state (sheet->workbook, TRUE);
 
 	sheet_selection_ant (sheet);
 }
@@ -99,7 +107,7 @@ application_clipboard_cut (Sheet *sheet, Range const *area)
 	app.clipboard_cut_range = *area;
 
 	/* No paste special for copies */
-	workbook_view_set_paste_state (sheet->workbook, 1);
+	workbook_view_set_paste_special_state (sheet->workbook, TRUE);
 
 	sheet_selection_ant (sheet);
 }
