@@ -257,14 +257,14 @@ x_selection_to_cell_region (char *data, int len)
 			if (p != data)
 				list = new_node (list, data, p, cur_col, rows);
 
+			cur_col++;
+			if (cur_col > cols)
+				cols = cur_col;
 			if (*p == '\n'){
-				rows++;
+				if (p [1])
+					rows++;
 				cur_col = 0;
-			} else {
-				cur_col++;
-				if (cur_col > cols)
-					cols = cur_col;
-			}
+			} 
 
 			data = p+1;
 		}
@@ -637,7 +637,11 @@ clipboard_paste_region (CommandContext *context,
 		return;
 	}
 
-	/* Now, trigger a grab of the X selection */
+	/*
+	 * Now, trigger a grab of the X selection.
+	 *
+	 * This will callback x_selection_received
+	 */
 	gtk_selection_convert (
 		dest_sheet->workbook->toplevel, GDK_SELECTION_PRIMARY,
 		GDK_TARGET_STRING, time);
