@@ -10,6 +10,7 @@
 #include <gnome.h>
 #include <glade/glade.h>
 #include "gnumeric.h"
+#include "workbook-view.h"
 #include "gnumeric-util.h"
 #include "gnumeric-sheet.h"
 #include "dialogs.h"
@@ -18,6 +19,7 @@
 #include "selection.h"
 #include "utils.h"
 #include "utils-dialog.h"
+#include "ranges.h"
 
 #define MAX_CLAUSE 6
 
@@ -70,7 +72,8 @@ typedef struct {
 
 
 static void
-dialog_cell_sort_adv(GtkWidget *widget, OrderBox *orderbox) {
+dialog_cell_sort_adv (GtkWidget *widget, OrderBox *orderbox)
+{
 	GladeXML *gui;
 	GtkWidget *check;
 	GtkWidget *rb1, *rb2;
@@ -85,24 +88,26 @@ dialog_cell_sort_adv(GtkWidget *widget, OrderBox *orderbox) {
 	}
 
 	dialog = glade_xml_get_widget (gui, "CellSortAdvanced");
-	check = glade_xml_get_widget (gui, "cell_sort_adv_case");
-	rb1   = glade_xml_get_widget (gui, "cell_sort_adv_value");
-	rb2   = glade_xml_get_widget (gui, "cell_sort_adv_text");
+	check  = glade_xml_get_widget (gui, "cell_sort_adv_case");
+	rb1    = glade_xml_get_widget (gui, "cell_sort_adv_value");
+	rb2    = glade_xml_get_widget (gui, "cell_sort_adv_text");
 	if (!dialog || !check || !rb1 || !rb2) {
 		g_warning ("Corrupt file cell-sort.glade\n");
+		gtk_object_unref (GTK_OBJECT (gui));
 		return;
 	}
 
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check), orderbox->cs);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(rb1), orderbox->val);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(rb2), !(orderbox->val));
-	btn = gnome_dialog_run(GNOME_DIALOG(dialog));
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check), orderbox->cs);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (rb1), orderbox->val);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (rb2), !(orderbox->val));
+	btn = gnome_dialog_run (GNOME_DIALOG (dialog));
 	if (btn == 0) {
-		orderbox->cs = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON (check));
-		orderbox->val = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON (rb1));	
+		orderbox->cs  = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check));
+		orderbox->val = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (rb1));	
 	}
 
-	gtk_object_destroy(GTK_OBJECT(dialog));
+	gtk_object_destroy (GTK_OBJECT (dialog));
+	gtk_object_unref (GTK_OBJECT (gui));
 }
 
 static OrderBox *
@@ -110,11 +115,11 @@ order_box_new (GtkWidget * parent, const gchar *frame_text,
 	       GList *names, gboolean empty)
 {
 	OrderBox *orderbox;
-	GtkWidget *hbox = gtk_hbox_new(FALSE, 2);
+	GtkWidget *hbox = gtk_hbox_new (FALSE, 2);
 
-	orderbox  = g_new(OrderBox, 1);
+	orderbox  = g_new (OrderBox, 1);
 	orderbox->parent = parent;
-	orderbox->main_frame = gtk_frame_new(frame_text);
+	orderbox->main_frame = gtk_frame_new (frame_text);
 
 	/* Set up the column names combo boxes */
 	orderbox->rangetext = gtk_combo_new ();
@@ -183,7 +188,7 @@ static char *
 order_box_get_text (OrderBox *orderbox, ClauseData *data)
 {
 	data->asc = gtk_radio_group_get_selected (orderbox->group);
-	data->cs = orderbox->cs;
+	data->cs  = orderbox->cs;
 	data->val = orderbox->val;
 	return gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (orderbox->rangetext)->entry));
 }
@@ -195,8 +200,8 @@ compare_values (const SortData * ain, const SortData * bin, int clause)
 	Value *a,  *b;
 	int ans = 0, fans = 0;
 
-	ca = ain->cells[ain->clauses[clause].offset];
-	cb = bin->cells[bin->clauses[clause].offset];
+	ca = ain->cells [ain->clauses [clause].offset];
+	cb = bin->cells [bin->clauses [clause].offset];
 
 	if (!ca)
 		a = value_new_int (0);
@@ -247,11 +252,10 @@ compare_values (const SortData * ain, const SortData * bin, int clause)
 					char *sa, *sb;
 					sa  = value_get_as_string (a);
 					sb  = value_get_as_string (b);
-					if (ain->clauses[clause].cs) {
-						ans = strcmp(sa, sb);
-					} else {
-						ans = strcasecmp(sa, sb);
-					}
+					if (ain->clauses [clause].cs)
+						ans = strcmp (sa, sb);
+					else
+						ans = strcasecmp (sa, sb);
 					g_free (sa);
 					g_free (sb);
 					break;
@@ -262,13 +266,19 @@ compare_values (const SortData * ain, const SortData * bin, int clause)
 		}
 	} else {
 		char *sa, *sb;
-		sa  = cell_get_text (ca);
-		sb  = cell_get_text (cb);
-		if (ain->clauses[clause].cs) {
-			ans = strcmp(sa, sb);
-		} else {
-			ans = strcasecmp(sa, sb);
-		}
+		if (ca)
+			sa = cell_get_text (ca);
+		else
+			sa = g_strdup ("0");
+		if (cb)
+			sb = cell_get_text (cb);
+		else
+			sb = g_strdup ("0");
+
+		if (ain->clauses [clause].cs)
+			ans = strcmp (sa, sb);
+		else
+			ans = strcasecmp (sa, sb);
 		g_free (sa);
 		g_free (sb);
 	}
@@ -284,9 +294,9 @@ compare_values (const SortData * ain, const SortData * bin, int clause)
 		fans = ain->clauses [clause].asc ? -1 :  1;
 
 	if (!ca)
-		value_release(a);
+		value_release (a);
 	if (!cb)
-		value_release(b);
+		value_release (b);
 
 	return fans;
 }
@@ -435,7 +445,7 @@ dialog_cell_sort_del_clause (GtkWidget *widget, SortFlow *sf)
 		sf->num_clause--;
 		order_box_remove  (sf->clauses [sf->num_clause]);
 		order_box_destroy (sf->clauses [sf->num_clause]);
-/* Fixme: bit nasty ! */
+/* FIXME: bit nasty ! */
 		gtk_container_queue_resize (GTK_CONTAINER (sf->dialog));
 		gtk_widget_show_all (sf->dialog);
 		sf->clauses [sf->num_clause] = NULL;
@@ -569,46 +579,36 @@ string_list_free (GList *list)
  * Main entry point for the Cell Sort dialog box
  */
 void
-dialog_cell_sort (Workbook * inwb, Sheet * sheet)
+dialog_cell_sort (Workbook *inwb, Sheet *sheet)
 {
 	GladeXML  *gui;
 	GtkWidget *table, *check, *rb1, *rb2;
 	int btn, lp, i;
-	int start_col, start_row, end_col, end_row;
-	const Range *sel;
+	Range sel, extent;
 	SortFlow sort_flow;
 
-	g_return_if_fail(inwb);
-	g_return_if_fail(sheet);
-	g_return_if_fail(IS_SHEET(sheet));
+	g_return_if_fail (inwb != NULL);
+	g_return_if_fail (sheet != NULL);
+	g_return_if_fail (IS_SHEET (sheet));
 
-	/* Find out what we are sorting and if we can sort it */
-	if ((sel = selection_first_range (sheet, FALSE)) == NULL) {
-		gnumeric_notice (inwb, GNOME_MESSAGE_BOX_ERROR,
-				 _("Selection must be a single range"));
-		return;
-	}
-
-	start_row = sel->start.row;
-	start_col = sel->start.col;
-	end_row   = sel->end.row;
-	end_col   = sel->end.col;
-
-	if (end_row >= SHEET_MAX_ROWS - 2 ||
-	    end_col >= SHEET_MAX_COLS - 2){
-		gnumeric_notice (inwb, GNOME_MESSAGE_BOX_ERROR,
-				 _("Selection must be a finite range"));
-		return;
-	}
+	if (!selection_is_simple (workbook_command_context_gui (inwb),
+				  sheet, _("sort")))
+		return;	
+	
+	sel = *(range_copy (selection_first_range (sheet, FALSE)));
+	extent = sheet_get_extent (sheet);
+       	if (sel.end.col >= SHEET_MAX_COLS - 2)
+		sel.end.col = extent.end.col;
+	if (sel.end.row >= SHEET_MAX_ROWS - 2)
+		sel.end.row = extent.end.row;
 
 	/* Init clauses */
-	sort_flow.max_col_clause = end_col - start_col + 1;
-	sort_flow.max_row_clause = end_row - start_row + 1;
+	sort_flow.max_col_clause = sel.end.col - sel.start.col + 1;
+	sort_flow.max_row_clause = sel.end.row - sel.start.row + 1;
 	sort_flow.num_clause = sort_flow.max_col_clause > 1 ? 2 : 1;
 	for (lp = 0; lp < MAX_CLAUSE; lp++)
 		sort_flow.clauses[lp] = NULL;
 
-
 	/* Get the dialog and check for errors */
 	gui = glade_xml_new (GNUMERIC_GLADEDIR "/cell-sort.glade", NULL);
 	if (!gui) {
@@ -623,6 +623,7 @@ dialog_cell_sort (Workbook * inwb, Sheet * sheet)
 	rb2   = glade_xml_get_widget (gui, "cell_sort_col_rb");
 	if (!sort_flow.dialog || !table || !check || !rb1 || !rb2) {
 		g_warning ("Corrupt file cell-sort.glade\n");
+		gtk_object_unref (GTK_OBJECT (gui));
 		return;
 	}
 
@@ -630,15 +631,19 @@ dialog_cell_sort (Workbook * inwb, Sheet * sheet)
 	sort_flow.wb = inwb;
 	sort_flow.header = FALSE;
 	sort_flow.columns = TRUE;
-	sort_flow.colnames_plain  = cell_sort_col_name_list (sheet, start_col, end_col, start_row, FALSE);
-	sort_flow.colnames_header = cell_sort_col_name_list (sheet, start_col, end_col, start_row, TRUE);
-	sort_flow.rownames_plain  = cell_sort_row_name_list (sheet, start_row, end_row, start_col, FALSE);
-	sort_flow.rownames_header = cell_sort_row_name_list (sheet, start_row, end_row, start_col, TRUE);
+	sort_flow.colnames_plain  = cell_sort_col_name_list (sheet, sel.start.col, sel.end.col,
+							     sel.start.row, FALSE);
+	sort_flow.colnames_header = cell_sort_col_name_list (sheet, sel.start.col, sel.end.col,
+							     sel.start.row, TRUE);
+	sort_flow.rownames_plain  = cell_sort_row_name_list (sheet, sel.start.row, sel.end.row,
+							     sel.start.col, FALSE);
+	sort_flow.rownames_header = cell_sort_row_name_list (sheet, sel.start.row, sel.end.row,
+							     sel.start.col, TRUE);
 	gtk_signal_connect (GTK_OBJECT (check), "toggled",
 			    GTK_SIGNAL_FUNC (dialog_cell_sort_header_toggled), &sort_flow);
-	gtk_signal_connect (GTK_OBJECT (rb1), "toggled",
+	gtk_signal_connect (GTK_OBJECT (rb1),   "toggled",
 			    GTK_SIGNAL_FUNC (dialog_cell_sort_rows_toggled),   &sort_flow);	
-	gtk_signal_connect (GTK_OBJECT (rb2), "toggled",
+	gtk_signal_connect (GTK_OBJECT (rb2),   "toggled",
 			    GTK_SIGNAL_FUNC (dialog_cell_sort_cols_toggled),   &sort_flow);
 
 	gnome_dialog_set_parent (GNOME_DIALOG (sort_flow.dialog), GTK_WINDOW (sort_flow.wb->toplevel));
@@ -672,37 +677,37 @@ dialog_cell_sort (Workbook * inwb, Sheet * sheet)
 					division = -1;
 					if (sort_flow.columns) {
 						if (sort_flow.header) {
-							for (i = 0; i < end_col - start_col + 1; i++) {
+							for (i = 0; i < sel.end.col - sel.start.col + 1; i++) {
 								if (!strcmp (txt, g_list_nth_data (sort_flow.colnames_header, i))) {
-									division = start_col + i;
+									division = sel.start.col + i;
 									break;
 								}
 							}
 						} else
 							division = col_from_name(txt);
-						if (division < start_col || division > end_col) {
+						if (division < sel.start.col || division > sel.end.col) {
 							gnumeric_notice (sort_flow.wb, GNOME_MESSAGE_BOX_ERROR,
 									 _("Column must be within range"));
 							sort_flow.retry = 1;
 						}
-						array [lp].offset = division - start_col;
+						array [lp].offset = division - sel.start.col;
 					} else {
 						if (sort_flow.header) {
-							for (i = 0; i < end_row - start_row + 1; i++) {
+							for (i = 0; i < sel.end.row - sel.start.row + 1; i++) {
 								if (!strcmp (txt, g_list_nth_data (sort_flow.rownames_header, i))) {
-									division = start_row + i;
+									division = sel.start.row + i;
 									break;
 								}
 							}
 						} else {
 							division = atoi(txt) - 1;
 						}
-						if (division < start_row || division > end_row) {
+						if (division < sel.start.row || division > sel.end.row) {
 							gnumeric_notice (sort_flow.wb, GNOME_MESSAGE_BOX_ERROR,
 									 _("Row must be within range"));
 							sort_flow.retry = 1;
 						}
-						array [lp].offset = division - start_row;
+						array [lp].offset = division - sel.start.row;
 					}
 				} else if (lp <= 0) {
 					gnumeric_notice (sort_flow.wb, GNOME_MESSAGE_BOX_ERROR,
@@ -714,14 +719,14 @@ dialog_cell_sort (Workbook * inwb, Sheet * sheet)
 			if (!sort_flow.retry) {
 				if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check)))
 					if (sort_flow.columns)
-						sort_cell_range (sheet, array, sort_flow.num_clause, start_col, start_row+1,
-								 end_col, end_row, sort_flow.columns);
+						sort_cell_range (sheet, array, sort_flow.num_clause, sel.start.col, sel.start.row + 1,
+								 sel.end.col, sel.end.row, sort_flow.columns);
 					else
-						sort_cell_range (sheet, array, sort_flow.num_clause, start_col+1, start_row,
-								 end_col, end_row, sort_flow.columns);
+						sort_cell_range (sheet, array, sort_flow.num_clause, sel.start.col + 1, sel.start.row,
+								 sel.end.col, sel.end.row, sort_flow.columns);
 				else
-					sort_cell_range (sheet, array, sort_flow.num_clause, start_col, start_row,
-							 end_col, end_row, sort_flow.columns);
+					sort_cell_range (sheet, array, sort_flow.num_clause, sel.start.col, sel.start.row,
+							 sel.end.col, sel.end.row, sort_flow.columns);
 			}
 			g_free (array);
 		} else if (btn == 1) {
@@ -730,9 +735,8 @@ dialog_cell_sort (Workbook * inwb, Sheet * sheet)
 		} else if (btn == 2) {
 			dialog_cell_sort_del_clause (NULL, &sort_flow);
 			sort_flow.retry = 1;
-		} else  {
+		} else
 			sort_flow.retry = 0;
-		}
 	}
 	while (sort_flow.retry || sort_flow.force_redisplay);
 
@@ -747,4 +751,6 @@ dialog_cell_sort (Workbook * inwb, Sheet * sheet)
 	string_list_free (sort_flow.colnames_header);
 	string_list_free (sort_flow.rownames_plain);
 	string_list_free (sort_flow.rownames_header);
+
+	gtk_object_unref (GTK_OBJECT (gui));
 }
