@@ -88,7 +88,8 @@ fill_list (state_t *state)
 
 	state->selected   = -1;
 
-	state->expr_names = names = expr_name_list (state->wb, FALSE);
+	/* FIXME: scoping issues here */
+	state->expr_names = names = expr_name_list (state->wb, NULL, FALSE);
 	
 	while (names) {
 		ExprName *expr_name = names->data;
@@ -165,11 +166,13 @@ grab_text_ok (state_t *state, gboolean update_list)
 	if (!name || (name[0] == '\0'))
 		return TRUE;
 	
-	expr_name = expr_name_lookup (state->wb, name);
+	/* FIXME: we need to be able to select names scope ideally */
+	expr_name = expr_name_lookup (state->wb, NULL, name);
 	if (expr_name)
 		expr_name_remove (expr_name);
 
-	expr_name = expr_name_create (state->wb, name,
+	/* FIXME: and here */
+	expr_name = expr_name_create (state->wb, NULL, name,
 				      value, &error);
 
 	if (expr_name == NULL) {
@@ -262,6 +265,12 @@ dialog_define_names (Workbook *wb)
 		printf ("Corrupt file names.glade\n");
 		return;
 	}
+	gnome_dialog_set_parent (GNOME_DIALOG (state.dia), 
+				 GTK_WINDOW (wb->toplevel));
+ 	gnome_dialog_editable_enters(GNOME_DIALOG(state.dia), 
+				     GTK_EDITABLE(state.name));
+ 	gnome_dialog_editable_enters(GNOME_DIALOG(state.dia), 
+				     GTK_EDITABLE(state.value));
 
 	fill_list (&state);
 
