@@ -12,6 +12,7 @@
 #include "gnumeric-util.h"
 #include "selection.h"
 #include "dialogs.h"
+#include "workbook-view.h"
 
 #define GLADE_FILE "delete-cells.glade"
 
@@ -47,17 +48,21 @@ dialog_delete_cells_impl (Workbook *wb, Sheet *sheet, GladeXML  *gui)
 		rows = ss->user.end.row - ss->user.start.row + 1;
 
 		if (i == 0)
-			sheet_shift_rows (sheet, ss->user.start.col + cols, 
+			sheet_shift_rows (workbook_command_context_gui (wb), sheet,
+					  ss->user.start.col + cols, 
 					  ss->user.start.row, 
 					  ss->user.end.row, -cols);
 		else if (i == 1)
-			sheet_shift_cols (sheet, ss->user.start.col,
+			sheet_shift_cols (workbook_command_context_gui (wb), sheet,
+					  ss->user.start.col,
 					  ss->user.end.col, 
 					  ss->user.start.row + rows, -rows);
 		else if (i == 2)
-			sheet_delete_row (sheet, ss->user.start.row, rows);
+			sheet_delete_rows (workbook_command_context_gui (wb), sheet,
+					   ss->user.start.row, rows);
 		else if (i == 3)
-			sheet_delete_col (sheet, ss->user.start.col, cols);
+			sheet_delete_cols (workbook_command_context_gui (wb), sheet,
+					   ss->user.start.col, cols);
 	}
 
 	/* If user closed the dialog with prejudice, it's already destroyed */
@@ -76,7 +81,7 @@ dialog_delete_cells (Workbook *wb, Sheet *sheet)
 	g_return_if_fail (sheet != NULL);
 	g_return_if_fail (IS_SHEET (sheet));
 
-	if (!selection_is_simple (sheet, _("delete cells")))
+	if (!selection_is_simple (workbook_command_context_gui (wb), sheet, _("delete cells")))
 		return;
 
 	ss = sheet->selections->data;
@@ -84,14 +89,14 @@ dialog_delete_cells (Workbook *wb, Sheet *sheet)
 	rows = ss->user.end.row - ss->user.start.row + 1;
 
 	/* short circuit the dialog if an entire row/column is selected */
-	if (ss->user.start.row == 0 && ss->user.end.row  >= SHEET_MAX_ROWS-1)
-	{
-		sheet_delete_col (sheet, ss->user.start.col, cols);
+	if (ss->user.start.row == 0 && ss->user.end.row  >= SHEET_MAX_ROWS-1) {
+		sheet_delete_cols (workbook_command_context_gui (wb), sheet,
+				   ss->user.start.col, cols);
 		return;
 	}
-	if (ss->user.start.col == 0 && ss->user.end.col  >= SHEET_MAX_COLS-1)
-	{
-		sheet_delete_row (sheet, ss->user.start.row, rows);
+	if (ss->user.start.col == 0 && ss->user.end.col  >= SHEET_MAX_COLS-1) {
+		sheet_delete_rows (workbook_command_context_gui (wb), sheet,
+				   ss->user.start.row, rows);
 		return;
 	}
 
