@@ -17,9 +17,10 @@ int sampling_tool         (Workbook *wb, Sheet *sheet, Range *input_range,
 int ftest_tool            (Workbook *wb, Sheet *sheet, Range *input_range1, 
 			   Range *input_range2, float_t alpha,
 			   data_analysis_output_t *dao);
-int regression_tool       (Workbook *wb, Sheet *sheet, Range *input_range1, 
-			   Range *input_range2, float_t alpha,
-			   data_analysis_output_t *dao);
+int regression_tool       (Workbook *wb, Sheet *sheet, Range *input_rangeys, 
+			   Range *input_rangexs, float_t alpha,
+			   data_analysis_output_t *dao, int intercept,
+			   int xdim);
 int ttest_paired_tool     (Workbook *wb, Sheet *sheet, Range *input_range1, 
 			   Range *input_range2, float_t mean_diff, float_t alpha,
 			   data_analysis_output_t *dao);
