@@ -1032,8 +1032,8 @@ static char *help_tbilleq = {
 	   "@SYNTAX=TBILLEQ(settlement,maturity,discount)\n"
 	   "@DESCRIPTION="
 	   "TBILLEQ function returns the bond-yield equivalent (BEY) for "
-	   "a treasury bill.  TBILLEQ is equivalent to (365 x discount) / "
-	   "(360 - discount x DSM) where DSM is the days between @settlement "
+	   "a treasury bill.  TBILLEQ is equivalent to (365 * discount) / "
+	   "(360 - discount * DSM) where DSM is the days between @settlement "
 	   "and @maturity. "
 	   "\n"
 	   "If @settlement is after @maturity or the @maturity is set to "
@@ -1050,7 +1050,7 @@ static Value *
 gnumeric_tbilleq (FunctionEvalInfo *ei, Value **argv)
 {
 	float_t settlement, maturity, discount;
-	float_t res, dsm;
+	float_t dsm, divisor;
 
 	settlement = get_serial_date (argv[0]);
 	maturity = get_serial_date (argv[1]);
@@ -1061,9 +1061,13 @@ gnumeric_tbilleq (FunctionEvalInfo *ei, Value **argv)
 	if (settlement > maturity || discount < 0 || dsm > 356)
                 return value_new_error (&ei->pos, gnumeric_err_NUM);
 
-	res = (365 * discount) / (360 - discount * dsm);
+	divisor = 360 - discount * dsm;
+	/* This test probably isn't right, but it is better that not checking
+	   at all.  --MW.  */
+	if (divisor == 0)
+		return value_new_error (&ei->pos, gnumeric_err_DIV0);
 
-	return value_new_float (res);
+	return value_new_float ((365 * discount) / divisor);
 }
 
 /***************************************************************************/
@@ -1140,7 +1144,7 @@ gnumeric_tbillyield (FunctionEvalInfo *ei, Value **argv)
 	
 	dsm = maturity - settlement;
 
-	if (settlement > maturity || pr < 0 || dsm > 356)
+	if (pr <= 0 || dsm <= 0 || dsm > 356)
                 return value_new_error (&ei->pos, gnumeric_err_NUM);
 
 	res = (100.0 - pr) / pr * (360.0 / dsm);
@@ -1877,6 +1881,238 @@ out:
 
 /***************************************************************************/
 
+static char *help_euro = {
+	N_("@FUNCTION=EURO\n"
+	   "@SYNTAX=EURO(currency)\n"
+	   "@DESCRIPTION="
+	   "EURO converts one Euro to a given national currency in the "
+	   "European monetary union.  Currency is one of the following:\n"
+	   "    ATS     (Austria)\n"
+	   "    BEF     (Belgium)\n"
+	   "    DEM     (Germany)\n"
+	   "    ESP     (Spain)\n"
+	   "    FIM     (Finland)\n"
+	   "    FRF     (France)\n"
+	   "    IEP     (Ireland)\n"
+	   "    ITL     (Italy)\n"
+	   "    LUF     (Luxemburg)\n"
+	   "    NLG     (Netherlands)\n"
+	   "    PTE     (Portugal)\n"
+	   "\n"
+	   "If the given currency is other than one of the above, EURO "
+	   "returns NUM! error. "
+	   "\n"
+	   "@EXAMPLES=\n"
+	   "EURO(\"DEM\") returns 1.95583."
+	   "\n"
+	   "@SEEALSO=")
+};
+
+static Value *
+gnumeric_euro (FunctionEvalInfo *ei, Value **argv)
+{
+        char *str = argv [0]->v.str->str;
+
+	switch (*str) {
+	case 'A':
+	  if (strncmp("ATS", str, 3) == 0)
+	    return value_new_float (13.7603);
+	  break;
+	case 'B':
+	  if (strncmp("BEF", str, 3) == 0)
+	    return value_new_float (40.3399);
+	  break;
+	case 'D':
+	  if (strncmp("DEM", str, 3) == 0)
+	    return value_new_float (1.95583);
+	  break;
+	case 'E':
+	  if (strncmp("ESP", str, 3) == 0)
+	    return value_new_float (166.386);
+	  break;
+	case 'F':
+	  if (strncmp("FIM", str, 3) == 0)
+	    return value_new_float (5.94573);
+	  else if (strncmp("FRF", str, 3) == 0)
+	    return value_new_float (6.55957);
+	  break;
+	case 'I':
+	  if (strncmp("IEP", str, 3) == 0)
+	    return value_new_float (0.787564);
+	  else if (strncmp("ITL", str, 3) == 0)
+	    return value_new_float (1936.27);
+	  break;
+	case 'L':
+	  if (strncmp("LUX", str, 3) == 0)
+	    return value_new_float (40.3399);
+	  break;
+	case 'N':
+	  if (strncmp("NLG", str, 3) == 0)
+	    return value_new_float (2.20371);
+	  break;
+	case 'P':
+	  if (strncmp("PTE", str, 3) == 0)
+	    return value_new_float (200.482);
+	  break;
+	default:
+	  break;
+	}
+
+	return value_new_error (&ei->pos, gnumeric_err_NUM);
+}
+
+/***************************************************************************/
+
+static char *help_price = {
+	N_("@FUNCTION=PRICE\n"
+	   "@SYNTAX=PRICE(settle,mat,rate,yield,redemption_price,frequency,basis)\n"
+	   "@DESCRIPTION="
+	   "\n"
+	   "@EXAMPLES=\n"
+	   "\n"
+	   "@SEEALSO=")
+};
+
+/*
+  <jody> Available frequencies : 1 = annual, 2 = semi, 4 = quarterly.
+  <jody> Available daycount basis 0 = 30/360 1 = Act/Act 2 = Act/360 3 = Act/365
+  4 = 30E/360
+*/
+
+static Value *
+gnumeric_price (FunctionEvalInfo *ei, Value **argv)
+{
+	return value_new_error (&ei->pos, "#UNIMPLEMENTED!");
+}
+
+/***************************************************************************/
+
+static char *help_yield = {
+	N_("@FUNCTION=YIELD\n"
+	   "@SYNTAX=YIELD(settle,mat,rate,price,redemption_price,frequency,basis)\n"
+	   "@DESCRIPTION="
+	   "\n"
+	   "@EXAMPLES=\n"
+	   "\n"
+	   "@SEEALSO=")
+};
+
+static Value *
+gnumeric_yield (FunctionEvalInfo *ei, Value **argv)
+{
+	return value_new_error (&ei->pos, "#UNIMPLEMENTED!");
+}
+
+/***************************************************************************/
+
+static char *help_yielddisc = {
+	N_("@FUNCTION=YIELDDISC\n"
+	   "@SYNTAX=YIELDDISC(settlement,maturity,pr,redemption,basis)\n"
+	   "@DESCRIPTION="
+	   "\n"
+	   "@EXAMPLES=\n"
+	   "\n"
+	   "@SEEALSO=")
+};
+
+static Value *
+gnumeric_yielddisc (FunctionEvalInfo *ei, Value **argv)
+{
+	return value_new_error (&ei->pos, "#UNIMPLEMENTED!");
+}
+
+/***************************************************************************/
+
+static char *help_yieldmat = {
+	N_("@FUNCTION=YIELDMAT\n"
+	   "@SYNTAX=YIELDMAT(settlement,maturity,issue,rate,pr,basis)\n"
+	   "@DESCRIPTION="
+	   "\n"
+	   "@EXAMPLES=\n"
+	   "\n"
+	   "@SEEALSO=")
+};
+
+static Value *
+gnumeric_yieldmat (FunctionEvalInfo *ei, Value **argv)
+{
+	return value_new_error (&ei->pos, "#UNIMPLEMENTED!");
+}
+
+/***************************************************************************/
+
+static char *help_oddfprice = {
+	N_("@FUNCTION=ODDFPRICE\n"
+	   "@SYNTAX=ODDFPRICE(settlement,maturity,issue,first_coupon,rate,yld,redemption,frequency,basis)\n"
+	   "@DESCRIPTION="
+	   "\n"
+	   "@EXAMPLES=\n"
+	   "\n"
+	   "@SEEALSO=")
+};
+
+static Value *
+gnumeric_oddfprice (FunctionEvalInfo *ei, Value **argv)
+{
+	return value_new_error (&ei->pos, "#UNIMPLEMENTED!");
+}
+
+/***************************************************************************/
+
+static char *help_oddfyield = {
+	N_("@FUNCTION=ODDFYIELD\n"
+	   "@SYNTAX=ODDFYIELD(settlement,maturity,issue,first_coupon,rate,pr,redemption,frequency,basis)\n"
+	   "@DESCRIPTION="
+	   "\n"
+	   "@EXAMPLES=\n"
+	   "\n"
+	   "@SEEALSO=")
+};
+
+static Value *
+gnumeric_oddfyield (FunctionEvalInfo *ei, Value **argv)
+{
+	return value_new_error (&ei->pos, "#UNIMPLEMENTED!");
+}
+
+/***************************************************************************/
+
+static char *help_oddlprice = {
+	N_("@FUNCTION=ODDLPRICE\n"
+	   "@SYNTAX=ODDLPRICE(settlement,maturity,last_interest,rate,yld,redemption,frequency,basis)\n"
+	   "@DESCRIPTION="
+	   "\n"
+	   "@EXAMPLES=\n"
+	   "\n"
+	   "@SEEALSO=")
+};
+
+static Value *
+gnumeric_oddlprice (FunctionEvalInfo *ei, Value **argv)
+{
+	return value_new_error (&ei->pos, "#UNIMPLEMENTED!");
+}
+
+/***************************************************************************/
+
+static char *help_oddlyield = {
+	N_("@FUNCTION=ODDLYIELD\n"
+	   "@SYNTAX=ODDLYIELD(settlement,maturity,last_interest,rate,pr,redemption,frequency,basis)\n"
+	   "@DESCRIPTION="
+	   "\n"
+	   "@EXAMPLES=\n"
+	   "\n"
+	   "@SEEALSO=")
+};
+
+static Value *
+gnumeric_oddlyield (FunctionEvalInfo *ei, Value **argv)
+{
+	return value_new_error (&ei->pos, "#UNIMPLEMENTED!");
+}
+
+/***************************************************************************/
+
 void
 finance_functions_init (void)
 {
@@ -1908,6 +2144,8 @@ finance_functions_init (void)
 			    &help_duration, gnumeric_duration);
 	function_add_args  (cat, "effect",   "ff",    "rate,nper",
 			    &help_effect,   gnumeric_effect);
+	function_add_args  (cat, "euro", "s", "currency",
+			    &help_euro,     gnumeric_euro);
 	function_add_args  (cat, "fv", "fffff", "rate,nper,pmt,pv,type",
 			    &help_fv,       gnumeric_fv);
 	function_add_args  (cat, "fvschedule", "fA", "pv,schedule",
@@ -1932,11 +2170,26 @@ finance_functions_init (void)
 			    &help_nper,     gnumeric_nper);
         function_add_nodes (cat, "npv",     0,      "",
 			    &help_npv,      gnumeric_npv);
+        function_add_args  (cat, "oddfprice", "????fffff",
+			    "settlement,maturity,issue,first_coupon,rate,yld,redemption,frequency,basis",
+			    &help_oddfprice,  gnumeric_oddfprice);
+        function_add_args  (cat, "oddfyield", "????fffff",
+			    "settlement,maturity,issue,first_coupon,rate,pr,redemption,frequency,basis",
+			    &help_oddfyield,  gnumeric_oddfyield);
+        function_add_args  (cat, "oddlprice", "???fffff",
+			    "settlement,maturity,last_interest,rate,yld,redemption,frequency,basis",
+			    &help_oddlprice,  gnumeric_oddlprice);
+        function_add_args  (cat, "oddlyield", "???fffff",
+			    "settlement,maturity,last_interest,rate,pr,redemption,frequency,basis",
+			    &help_oddlyield,  gnumeric_oddlyield);
 	function_add_args  (cat, "pmt", "fff|ff", "rate,nper,pv[,fv,type]",
 			    &help_pmt,      gnumeric_pmt);
 	function_add_args  (cat, "ppmt", "ffff|ff",
 			    "rate,per,nper,pv[,fv,type]",
 			    &help_ppmt,     gnumeric_ppmt);
+        function_add_args  (cat, "price", "??fff|ff",
+			    "settle,mat,rate,yield,redemption_price,frequency,basis",
+			    &help_price, gnumeric_price);
 	function_add_args  (cat, "pricedisc", "??ff|f",
 			    "settlement,maturity,discount,redemption[,basis]",
 			    &help_pricedisc,  gnumeric_pricedisc);
@@ -1961,10 +2214,19 @@ finance_functions_init (void)
 			    &help_tbilleq,  gnumeric_tbilleq);
         function_add_args  (cat, "tbillprice", "??f",
 			    "settlement,maturity,discount",
-			    &help_tbillprice,  gnumeric_tbillprice);
+			    &help_tbillprice, gnumeric_tbillprice);
         function_add_args  (cat, "tbillyield", "??f",
 			    "settlement,maturity,pr",
-			    &help_tbillyield,  gnumeric_tbillyield);
+			    &help_tbillyield, gnumeric_tbillyield);
+        function_add_args  (cat, "yield", "??fff|ff",
+			    "settle,mat,rate,price,redemption_price,frequency,basis",
+			    &help_yield, gnumeric_yield);
+        function_add_args  (cat, "yielddisc", "??fff",
+			    "settlement,maturity,pr,redemption,basis",
+			    &help_yielddisc,  gnumeric_yielddisc);
+        function_add_args  (cat, "yieldmat", "???fff",
+			    "settlement,maturity,issue,rate,pr,basis",
+			    &help_yieldmat,  gnumeric_yieldmat);
         function_add_args  (cat, "xirr", "AA|f", "values,dates[,guess]",
 			    &help_xirr,     gnumeric_xirr);
         function_add_args  (cat, "xnpv", "fAA", "rate,values,dates",
