@@ -19,6 +19,7 @@
 #include "clipboard.h"
 #include "selection.h"
 #include "utils.h"
+#include "workbook-view.h"
 
 static GnomeCanvasItem *item_cursor_parent_class;
 
@@ -607,6 +608,7 @@ static void
 item_cursor_do_action (ItemCursor *item_cursor, ActionType action, guint32 time)
 {
 	Sheet *sheet = item_cursor->sheet;
+	Workbook *wb = sheet->workbook;
 	int   col = item_cursor->pos.start.col;
 	int   row = item_cursor->pos.start.row;
 
@@ -615,43 +617,47 @@ item_cursor_do_action (ItemCursor *item_cursor, ActionType action, guint32 time)
 		return;
 
 	case ACTION_COPY_CELLS:
-		if (!item_cursor_target_region_ok (item_cursor)){
+		if (!item_cursor_target_region_ok (item_cursor)) {
 			return;
 		}
-		if (!sheet_selection_copy (sheet))
+		if (!sheet_selection_copy (workbook_command_context_gui (wb), sheet))
 			return;
-		sheet_selection_paste (sheet, col, row, PASTE_ALL_TYPES, time);
+		sheet_selection_paste (workbook_command_context_gui (wb), sheet,
+				       col, row, PASTE_ALL_TYPES, time);
 		return;
 
 	case ACTION_MOVE_CELLS:
 		if (!item_cursor_target_region_ok (item_cursor))
 			return;
-		if (!sheet_selection_cut (sheet))
+		if (!sheet_selection_cut (workbook_command_context_gui (wb), sheet))
 			return;
-		sheet_selection_paste (sheet, col, row, PASTE_ALL_TYPES, time);
+		sheet_selection_paste (workbook_command_context_gui (wb), sheet,
+				       col, row, PASTE_ALL_TYPES, time);
 		return;
 
 	case ACTION_COPY_FORMATS:
 		if (!item_cursor_target_region_ok (item_cursor))
 			return;
-		if (!sheet_selection_copy (sheet))
+		if (!sheet_selection_copy (workbook_command_context_gui (wb), sheet))
 			return;
-		sheet_selection_paste (sheet, col, row, PASTE_FORMATS, time);
+		sheet_selection_paste (workbook_command_context_gui (wb), sheet,
+				       col, row, PASTE_FORMATS, time);
 		return;
 
 	case ACTION_COPY_VALUES:
 		if (!item_cursor_target_region_ok (item_cursor))
 			return;
-		if (!sheet_selection_copy (sheet))
+		if (!sheet_selection_copy (workbook_command_context_gui (wb), sheet))
 			return;
-		sheet_selection_paste (sheet, col, row, PASTE_VALUES, time);
+		sheet_selection_paste (workbook_command_context_gui (wb), sheet,
+				       col, row, PASTE_VALUES, time);
 		return;
 
 	case ACTION_SHIFT_DOWN_AND_COPY:
 	case ACTION_SHIFT_RIGHT_AND_COPY:
 	case ACTION_SHIFT_DOWN_AND_MOVE:
 	case ACTION_SHIFT_RIGHT_AND_MOVE:
-		g_warning ("Operation not yet implemeneted\n");
+		g_warning ("Operation not yet implemented\n");
 	}
 }
 
