@@ -22,6 +22,7 @@
 #include "application.h"
 #include "workbook-cmd-format.h"
 #include "pattern.h"
+#include "workbook-view.h"
 
 static GnomeCanvasItemClass *item_grid_parent_class;
 
@@ -66,7 +67,7 @@ item_grid_realize (GnomeCanvasItem *item)
 	 * This makes the redraws when the canvas scrolls flicker less.
 	 */
 	style = gtk_style_copy (GTK_WIDGET (item->canvas)->style);
-	style->bg[GTK_STATE_NORMAL] = gs_white;
+	style->bg [GTK_STATE_NORMAL] = gs_white;
 	gtk_widget_set_style (GTK_WIDGET (item->canvas), style);
 	gtk_style_unref (style);
 
@@ -90,7 +91,7 @@ item_grid_realize (GnomeCanvasItem *item)
 	/* Find out how we need to draw the selection with the current visual */
 	visual = gtk_widget_get_visual (GTK_WIDGET (canvas));
 
-	switch (visual->type){
+	switch (visual->type) {
 	case GDK_VISUAL_STATIC_GRAY:
 	case GDK_VISUAL_TRUE_COLOR:
 	case GDK_VISUAL_STATIC_COLOR:
@@ -153,7 +154,7 @@ item_grid_find_col (ItemGrid *item_grid, int x, int *col_origin)
 	do {
 		ColRowInfo *ci = sheet_col_get_info (item_grid->sheet, col);
 
-		if (x >= pixel && x <= pixel + ci->pixels){
+		if (x >= pixel && x <= pixel + ci->pixels) {
 			if (col_origin)
 				*col_origin = pixel;
 			return col;
@@ -184,7 +185,7 @@ item_grid_find_row (ItemGrid *item_grid, int y, int *row_origin)
 	do {
 		ColRowInfo *ri = sheet_row_get_info (item_grid->sheet, row);
 
-		if (y >= pixel && y <= pixel + ri->pixels){
+		if (y >= pixel && y <= pixel + ri->pixels) {
 			if (row_origin)
 				*row_origin = pixel;
 			return row;
@@ -215,7 +216,7 @@ item_grid_invert_gc (ItemGrid *item_grid)
 	gc = item_grid->gc;
 	gdk_gc_set_clip_rectangle (gc, NULL);
 
-	if (item_grid->visual_is_paletted){
+	if (item_grid->visual_is_paletted) {
 		gdk_gc_set_function (gc, GDK_XOR);
 		gdk_gc_set_foreground (gc, &gs_white);
 	} else {
@@ -398,7 +399,7 @@ item_grid_draw (GnomeCanvasItem *item, GdkDrawable *drawable, int x, int y, int
 	gdk_gc_set_function (item_grid->gc, GDK_COPY);
 
 	row = paint_row;
-	for (y_paint = -diff_y; y_paint < end_y && row < SHEET_MAX_ROWS; row++){
+	for (y_paint = -diff_y; y_paint < end_y && row < SHEET_MAX_ROWS; row++) {
 		ColRowInfo *ri;
 
 		ri = sheet_row_get_info (sheet, row);
@@ -412,7 +413,7 @@ item_grid_draw (GnomeCanvasItem *item, GdkDrawable *drawable, int x, int y, int
 			cell = sheet_cell_get (sheet, col, row);
 
 			/* If the cell does not exist paint it as an empty cell */
-			if (cell == NULL){
+			if (cell == NULL) {
 				item_grid_paint_empty_cell (
 					drawable, item_grid, ci, ri,
 					col, row, x_paint, y_paint,
@@ -423,7 +424,7 @@ item_grid_draw (GnomeCanvasItem *item, GdkDrawable *drawable, int x, int y, int
 					x_paint, y_paint);
 			}
 
-			if (cell_is_blank (cell) && (ri->pos != -1)){
+			if (cell_is_blank (cell) && (ri->pos != -1)) {
 				/*
 				 * If there was no cell, and the row has any cell allocated
 				 * (indicated by ri->pos != -1)
@@ -437,13 +438,13 @@ item_grid_draw (GnomeCanvasItem *item, GdkDrawable *drawable, int x, int y, int
 				 * cell, adjust x to point to the beginning
 				 * of that cell.
 				 */
-				if (cell){
+				if (cell) {
 					int i, count, end_col;
 
 					/*
 					 * Either adjust the left part
 					 */
-					for (i = cell->col->pos; i < col; i++){
+					for (i = cell->col->pos; i < col; i++) {
 						ColRowInfo *tci;
 
 						tci = sheet_col_get_info (sheet, i);
@@ -453,7 +454,7 @@ item_grid_draw (GnomeCanvasItem *item, GdkDrawable *drawable, int x, int y, int
 					/*
 					 * Or adjust the right part
 					 */
-					for (i = col; i < cell->col->pos; i++){
+					for (i = col; i < cell->col->pos; i++) {
 						ColRowInfo *tci;
 
 						tci = sheet_col_get_info (
@@ -475,7 +476,7 @@ item_grid_draw (GnomeCanvasItem *item, GdkDrawable *drawable, int x, int y, int
 					 */
 					end_col = cell->col->pos + count;
 
-					for (i = col+1; i < end_col; i++, col++){
+					for (i = col+1; i < end_col; i++, col++) {
 						ColRowInfo *tci;
 
 						tci = sheet_col_get_info (
@@ -494,7 +495,7 @@ item_grid_draw (GnomeCanvasItem *item, GdkDrawable *drawable, int x, int y, int
 	item_grid_invert_gc (item_grid);
 
 	row = paint_row;
-	for (y_paint = -diff_y; y_paint < end_y && row < SHEET_MAX_ROWS; row++){
+	for (y_paint = -diff_y; y_paint < end_y && row < SHEET_MAX_ROWS; row++) {
 		ColRowInfo *ri, *ci;
 
 		ri = sheet_row_get_info (sheet, row);
@@ -542,21 +543,21 @@ context_destroy_menu (GtkWidget *widget)
 static void
 context_cut_cmd (GtkWidget *widget, Sheet *sheet)
 {
-	sheet_selection_cut (sheet);
+	sheet_selection_cut (workbook_command_context_gui (sheet->workbook), sheet);
 	context_destroy_menu (widget);
 }
 
 static void
 context_copy_cmd (GtkWidget *widget, Sheet *sheet)
 {
-	sheet_selection_copy (sheet);
+	sheet_selection_copy (workbook_command_context_gui (sheet->workbook), sheet);
 	context_destroy_menu (widget);
 }
 
 static void
 context_paste_cmd (GtkWidget *widget, Sheet *sheet)
 {
-	sheet_selection_paste (sheet,
+	sheet_selection_paste (workbook_command_context_gui (sheet->workbook), sheet,
 			       sheet->cursor_col,
 			       sheet->cursor_row,
 			       PASTE_DEFAULT,
@@ -571,7 +572,7 @@ context_paste_special_cmd (GtkWidget *widget, Sheet *sheet)
 
 	flags = dialog_paste_special (sheet->workbook);
 	if (flags != 0)
-		sheet_selection_paste (sheet,
+		sheet_selection_paste (workbook_command_context_gui (sheet->workbook), sheet,
 				       sheet->cursor_col,
 				       sheet->cursor_row,
 				       flags,
@@ -596,7 +597,7 @@ context_delete_cmd (GtkWidget *widget, Sheet *sheet)
 static void
 context_clear_cmd (GtkWidget *widget, Sheet *sheet)
 {
-	sheet_selection_clear_content (sheet);
+	sheet_selection_clear_content (workbook_command_context_gui (sheet->workbook), sheet);
 	context_destroy_menu (widget);
 }
 
@@ -876,7 +877,7 @@ item_grid_sliding_callback (gpointer data)
 	row = item_grid->sliding_row;
 
 	if (item_grid->sliding_x < 0){
-		if (gsheet->top_col){
+		if (gsheet->left_col){
 			change = 1;
 			if (item_grid->sliding_x >= -8)
 				col = 1;
@@ -884,7 +885,7 @@ item_grid_sliding_callback (gpointer data)
 				col = 10;
 			else
 				col = 50;
-			col = gsheet->top_col - col;
+			col = gsheet->left_col - col;
 			if (col < 0)
 				col = 0;
 		} else
@@ -1048,7 +1049,7 @@ item_grid_event (GnomeCanvasItem *item, GdkEvent *event)
 			else if (y >= row + height)
 				dy = y - height - row;
 
-			if ((!dx || (dx < 0 && !gsheet->top_col) ||
+			if ((!dx || (dx < 0 && !gsheet->left_col) ||
 			     (dx >= 0 && gsheet->last_full_col == SHEET_MAX_COLS-1)) &&
 			    (!dy || (dy < 0 && !gsheet->top_row) ||
 			     (dy >= 0 && gsheet->last_full_row == SHEET_MAX_ROWS-1))){
