@@ -14,9 +14,10 @@
 #include "format.h"
 #include "cursors.h"
 #include "number-match.h"
-#include "dump.h"
 #include "main.h"
+#include "func.h"
 #include "application.h"
+#include "print-info.h"
 #include "global-gnome-font.h"
 
 #include "../plugins/excel/boot.h"
@@ -30,6 +31,7 @@
 /* The debugging level */
 int gnumeric_debugging = 0;
 int style_debugging = 0;
+int immediate_exit_flag = 0;
 extern int ms_excel_read_debug;
 extern int ms_excel_formula_debug;
 extern int ms_excel_color_debug;
@@ -50,6 +52,8 @@ const struct poptOption gnumeric_popt_options [] = {
 	  N_("Enables some debugging functions"), N_("LEVEL") },
 	{ "debug_styles", '\0', POPT_ARG_INT, &style_debugging, 0,
 	  N_("Enables some style related debugging functions"), N_("LEVEL") },
+	{ "quit", '\0', POPT_ARG_NONE, &immediate_exit_flag, 0,
+	  N_("Exit immediately after loading the selected books (useful for testing)."), NULL },
 
 	{ "debug_excel_read", '\0', POPT_ARG_INT,
 	    &ms_excel_read_debug, 0,
@@ -74,7 +78,7 @@ const struct poptOption gnumeric_popt_options [] = {
 	{ "debug_ole", '\0', POPT_ARG_NONE,
 	    &libole2_debug, 0,
 	  N_("Enables extra consistancy checking while reading ole files"),
-	  N_("LEVEL") },
+	  NULL  },
 	{ NULL, '\0', 0, NULL, 0 }
 };
 
@@ -100,6 +104,7 @@ gnumeric_main (void *closure, int argc, char *argv [])
 	constants_init ();
 	functions_init ();
 	expr_name_init ();
+	print_init ();
 	plugins_init ();
 
 	/* The statically linked in file formats */
@@ -113,8 +118,8 @@ gnumeric_main (void *closure, int argc, char *argv [])
 	if (startup_glade_file)
 		glade_xml_new (startup_glade_file, NULL);
 
-	if (dump_file_name){
-		dump_functions (dump_file_name);
+	if (dump_file_name) {
+		function_dump_defs (dump_file_name);
 		exit (0);
 	}
 
@@ -153,9 +158,11 @@ gnumeric_main (void *closure, int argc, char *argv [])
 	bonobo_activate ();
 #endif
 	
-	gtk_main ();
+	if (!immediate_exit_flag)
+		gtk_main ();
 
 	excel_shutdown ();
+	print_shutdown ();
 	cursors_shutdown ();
 	format_match_finish ();
 	format_color_shutdown ();
