@@ -49,6 +49,7 @@ static void  alloc_glist     (GList *l);
 static void  forget_glist    (GList *list);
 static void  forget_array    (GList *array);
 static void  forget_tree     (ExprTree *tree);
+static void  release_const_tree (ExprTree *tree);
 static void  alloc_list_free (void); 
 static Value*v_new (void);
 static void  v_forget (Value *v);
@@ -122,19 +123,23 @@ build_binop (ExprTree *l, Operation op, ExprTree *r)
 }
 
 static ExprTree *
-build_array_formula (ExprTree *func,
-		     ExprTree *expr_num_cols, ExprTree *expr_num_rows,
-		     ExprTree *expr_x, ExprTree *expr_y)
+build_array_formula (ExprTree *func, int cols, int rows, int x, int y)
 {
-	int const num_cols = expr_tree_get_const_int (expr_num_cols);
-	int const num_rows = expr_tree_get_const_int (expr_num_rows);
-	int const x = expr_tree_get_const_int (expr_x);
-	int const y = expr_tree_get_const_int (expr_y);
-	ExprTree * res = expr_tree_array_formula (x, y, num_rows, num_cols);
+	ExprTree *res = expr_tree_array_formula (x, y, rows, cols);
+
 	res->u.array.corner.func.expr = func;
 	return res;
 }
 
+static void
+release_const_tree (ExprTree *tree)
+{
+	g_assert (tree->oper == OPER_CONSTANT);
+
+	g_free (tree->u.constant);
+	g_free (tree);
+}
+
 static ExprTree *
 build_array (GList *cols)
 {
@@ -168,7 +173,8 @@ build_array (GList *cols)
 
 			value_array_set (array, x, y, v);
 			v_forget (v);
-
+			g_free (expr);
+			
 			x++;
 			row = g_list_next (row);
 		}
@@ -188,7 +194,7 @@ build_array (GList *cols)
 int yyparse(void);
 
 
-#line 170 "parser.y"
+#line 176 "parser.y"
 typedef union {
 	ExprTree *tree;
 	CellRef  *cell;
@@ -273,11 +279,11 @@ static const short yyrhs[] = {    38,
 
 #if YYDEBUG != 0
 static const short yyrline[] = { 0,
-   195,   197,   201,   204,   205,   206,   207,   208,   209,   210,
-   211,   212,   213,   214,   215,   216,   217,   218,   219,   220,
-   222,   223,   224,   226,   230,   235,   249,   255,   259,   264,
-   270,   274,   279,   282,   283,   286,   290,   298,   306,   309,
-   313,   318
+   201,   203,   221,   224,   225,   226,   227,   228,   229,   230,
+   231,   232,   233,   234,   235,   236,   237,   238,   239,   240,
+   242,   243,   244,   246,   250,   255,   269,   275,   279,   284,
+   290,   294,   299,   302,   303,   306,   310,   318,   326,   329,
+   333,   338
 };
 #endif
 
@@ -888,114 +894,128 @@ yyreduce:
   switch (yyn) {
 
 case 1:
-#line 195 "parser.y"
+#line 201 "parser.y"
 { *parser_result = yyvsp[0].tree; ;
     break;}
 case 2:
-#line 197 "parser.y"
+#line 203 "parser.y"
 {
-		*parser_result = build_array_formula (yyvsp[-12].tree, yyvsp[-7].tree, yyvsp[-9].tree, yyvsp[-1].tree, yyvsp[-4].tree) ;
+		const int num_cols = expr_tree_get_const_int (yyvsp[-7].tree);
+		const int num_rows = expr_tree_get_const_int (yyvsp[-9].tree);
+		const int x = expr_tree_get_const_int (yyvsp[-1].tree);
+		const int y = expr_tree_get_const_int (yyvsp[-4].tree);
+
+		*parser_result = build_array_formula (yyvsp[-12].tree, num_cols, num_rows, x, y);
+
+		/*
+		 * Notice that we have no use for the ExprTrees for the NUMBERS,
+		 * so we deallocate them.
+		 */
+		release_const_tree (yyvsp[-7].tree);
+		release_const_tree (yyvsp[-9].tree);
+		release_const_tree (yyvsp[-1].tree);
+		release_const_tree (yyvsp[-4].tree);
 	;
     break;}
 case 3:
-#line 201 "parser.y"
+#line 221 "parser.y"
 { parser_error = PARSE_ERR_SYNTAX; ;
     break;}
 case 4:
-#line 204 "parser.y"
-{ yyval.tree = yyvsp[0].tree; ;
-    break;}
-case 5:
-#line 205 "parser.y"
-{ yyval.tree = yyvsp[0].tree; ;
-    break;}
-case 6:
-#line 206 "parser.y"
-{ yyval.tree = yyvsp[0].tree; ;
-    break;}
-case 7:
-#line 207 "parser.y"
-{ yyval.tree = yyvsp[0].tree; ;
-    break;}
-case 8:
-#line 208 "parser.y"
-{ yyval.tree = build_binop (yyvsp[-2].tree, OPER_ADD,       yyvsp[0].tree); ;
-    break;}
-case 9:
-#line 209 "parser.y"
-{ yyval.tree = build_binop (yyvsp[-2].tree, OPER_SUB,       yyvsp[0].tree); ;
-    break;}
-case 10:
-#line 210 "parser.y"
-{ yyval.tree = build_binop (yyvsp[-2].tree, OPER_MULT,      yyvsp[0].tree); ;
-    break;}
-case 11:
-#line 211 "parser.y"
-{ yyval.tree = build_binop (yyvsp[-2].tree, OPER_DIV,       yyvsp[0].tree); ;
-    break;}
-case 12:
-#line 212 "parser.y"
-{ yyval.tree = build_binop (yyvsp[-2].tree, OPER_EXP,       yyvsp[0].tree); ;
-    break;}
-case 13:
-#line 213 "parser.y"
-{ yyval.tree = build_binop (yyvsp[-2].tree, OPER_CONCAT,    yyvsp[0].tree); ;
-    break;}
-case 14:
-#line 214 "parser.y"
-{ yyval.tree = build_binop (yyvsp[-2].tree, OPER_EQUAL,     yyvsp[0].tree); ;
-    break;}
-case 15:
-#line 215 "parser.y"
-{ yyval.tree = build_binop (yyvsp[-2].tree, OPER_LT,        yyvsp[0].tree); ;
-    break;}
-case 16:
-#line 216 "parser.y"
-{ yyval.tree = build_binop (yyvsp[-2].tree, OPER_GT,        yyvsp[0].tree); ;
-    break;}
-case 17:
-#line 217 "parser.y"
-{ yyval.tree = build_binop (yyvsp[-2].tree, OPER_GTE,       yyvsp[0].tree); ;
-    break;}
-case 18:
-#line 218 "parser.y"
-{ yyval.tree = build_binop (yyvsp[-2].tree, OPER_NOT_EQUAL, yyvsp[0].tree); ;
-    break;}
-case 19:
-#line 219 "parser.y"
-{ yyval.tree = build_binop (yyvsp[-2].tree, OPER_LTE,       yyvsp[0].tree); ;
-    break;}
-case 20:
-#line 220 "parser.y"
-{ yyval.tree = yyvsp[-1].tree; ;
-    break;}
-case 21:
-#line 222 "parser.y"
-{ yyval.tree = build_unary_op (OPER_PERCENT, yyvsp[-1].tree); ;
-    break;}
-case 22:
-#line 223 "parser.y"
-{ yyval.tree = build_unary_op (OPER_NEG, yyvsp[0].tree); ;
-    break;}
-case 23:
 #line 224 "parser.y"
 { yyval.tree = yyvsp[0].tree; ;
     break;}
-case 24:
+case 5:
+#line 225 "parser.y"
+{ yyval.tree = yyvsp[0].tree; ;
+    break;}
+case 6:
 #line 226 "parser.y"
+{ yyval.tree = yyvsp[0].tree; ;
+    break;}
+case 7:
+#line 227 "parser.y"
+{ yyval.tree = yyvsp[0].tree; ;
+    break;}
+case 8:
+#line 228 "parser.y"
+{ yyval.tree = build_binop (yyvsp[-2].tree, OPER_ADD,       yyvsp[0].tree); ;
+    break;}
+case 9:
+#line 229 "parser.y"
+{ yyval.tree = build_binop (yyvsp[-2].tree, OPER_SUB,       yyvsp[0].tree); ;
+    break;}
+case 10:
+#line 230 "parser.y"
+{ yyval.tree = build_binop (yyvsp[-2].tree, OPER_MULT,      yyvsp[0].tree); ;
+    break;}
+case 11:
+#line 231 "parser.y"
+{ yyval.tree = build_binop (yyvsp[-2].tree, OPER_DIV,       yyvsp[0].tree); ;
+    break;}
+case 12:
+#line 232 "parser.y"
+{ yyval.tree = build_binop (yyvsp[-2].tree, OPER_EXP,       yyvsp[0].tree); ;
+    break;}
+case 13:
+#line 233 "parser.y"
+{ yyval.tree = build_binop (yyvsp[-2].tree, OPER_CONCAT,    yyvsp[0].tree); ;
+    break;}
+case 14:
+#line 234 "parser.y"
+{ yyval.tree = build_binop (yyvsp[-2].tree, OPER_EQUAL,     yyvsp[0].tree); ;
+    break;}
+case 15:
+#line 235 "parser.y"
+{ yyval.tree = build_binop (yyvsp[-2].tree, OPER_LT,        yyvsp[0].tree); ;
+    break;}
+case 16:
+#line 236 "parser.y"
+{ yyval.tree = build_binop (yyvsp[-2].tree, OPER_GT,        yyvsp[0].tree); ;
+    break;}
+case 17:
+#line 237 "parser.y"
+{ yyval.tree = build_binop (yyvsp[-2].tree, OPER_GTE,       yyvsp[0].tree); ;
+    break;}
+case 18:
+#line 238 "parser.y"
+{ yyval.tree = build_binop (yyvsp[-2].tree, OPER_NOT_EQUAL, yyvsp[0].tree); ;
+    break;}
+case 19:
+#line 239 "parser.y"
+{ yyval.tree = build_binop (yyvsp[-2].tree, OPER_LTE,       yyvsp[0].tree); ;
+    break;}
+case 20:
+#line 240 "parser.y"
+{ yyval.tree = yyvsp[-1].tree; ;
+    break;}
+case 21:
+#line 242 "parser.y"
+{ yyval.tree = build_unary_op (OPER_PERCENT, yyvsp[-1].tree); ;
+    break;}
+case 22:
+#line 243 "parser.y"
+{ yyval.tree = build_unary_op (OPER_NEG, yyvsp[0].tree); ;
+    break;}
+case 23:
+#line 244 "parser.y"
+{ yyval.tree = yyvsp[0].tree; ;
+    break;}
+case 24:
+#line 246 "parser.y"
 {
 		yyval.tree = yyvsp[0].tree;
 	;
     break;}
 case 25:
-#line 230 "parser.y"
+#line 250 "parser.y"
 {
 		yyval.tree = build_array (yyvsp[-1].list);
 		forget_array (yyvsp[-1].list);
 	;
     break;}
 case 26:
-#line 235 "parser.y"
+#line 255 "parser.y"
 {
 		yyval.tree = p_new (ExprTree);
 		yyval.tree->ref_count  = 1;
@@ -1010,41 +1030,41 @@ case 26:
 	;
     break;}
 case 27:
-#line 249 "parser.y"
+#line 269 "parser.y"
 {
 		yyval.tree = yyvsp[-3].tree;
 		yyval.tree->u.function.arg_list = yyvsp[-1].list;
 	;
     break;}
 case 28:
-#line 255 "parser.y"
+#line 275 "parser.y"
 {
 		yyval.tree = yyvsp[0].tree;
 	;
     break;}
 case 29:
-#line 259 "parser.y"
+#line 279 "parser.y"
 {
 	        yyval.tree = yyvsp[0].tree;
 		yyval.tree->u.ref.sheet = yyvsp[-2].sheetref;
 	;
     break;}
 case 30:
-#line 264 "parser.y"
+#line 284 "parser.y"
 {
 	        yyval.tree = yyvsp[0].tree;
 		yyval.tree->u.ref.sheet = yyvsp[-2].sheetref;
 	;
     break;}
 case 31:
-#line 270 "parser.y"
+#line 290 "parser.y"
 {
 		yyval.list = g_list_prepend (NULL, yyvsp[0].tree);
 		alloc_glist (yyval.list);
         ;
     break;}
 case 32:
-#line 274 "parser.y"
+#line 294 "parser.y"
 {
 		forget_glist (yyvsp[0].list);
 		yyval.list = g_list_prepend (yyvsp[0].list, yyvsp[-2].tree);
@@ -1052,26 +1072,26 @@ case 32:
 	;
     break;}
 case 33:
-#line 279 "parser.y"
+#line 299 "parser.y"
 { yyval.list = NULL; ;
     break;}
 case 34:
-#line 282 "parser.y"
+#line 302 "parser.y"
 { yyval.tree = yyvsp[0].tree; ;
     break;}
 case 35:
-#line 283 "parser.y"
+#line 303 "parser.y"
 { yyval.tree = yyvsp[0].tree; ;
     break;}
 case 36:
-#line 286 "parser.y"
+#line 306 "parser.y"
 {
 		yyval.list = g_list_prepend (NULL, yyvsp[0].tree);
 		alloc_glist (yyval.list);
         ;
     break;}
 case 37:
-#line 290 "parser.y"
+#line 310 "parser.y"
 {
 		if (parser_array_col_separator == ',') {
 			forget_glist (yyvsp[0].list);
@@ -1082,7 +1102,7 @@ case 37:
 	;
     break;}
 case 38:
-#line 298 "parser.y"
+#line 318 "parser.y"
 {
 		if (parser_array_col_separator == '\\') {
 			forget_glist (yyvsp[0].list);
@@ -1093,18 +1113,18 @@ case 38:
 	;
     break;}
 case 39:
-#line 306 "parser.y"
+#line 326 "parser.y"
 { yyval.list = NULL; ;
     break;}
 case 40:
-#line 309 "parser.y"
+#line 329 "parser.y"
 {
 		yyval.list = g_list_prepend (NULL, yyvsp[0].list);
 		alloc_glist (yyval.list);
         ;
     break;}
 case 41:
-#line 313 "parser.y"
+#line 333 "parser.y"
 {
 		forget_glist (yyvsp[0].list);
 		yyval.list = g_list_prepend (yyvsp[0].list, yyvsp[-2].list);
@@ -1112,7 +1132,7 @@ case 41:
 	;
     break;}
 case 42:
-#line 318 "parser.y"
+#line 338 "parser.y"
 { yyval.list = NULL; ;
     break;}
 }
@@ -1313,7 +1333,7 @@ yyerrhandle:
   yystate = yyn;
   goto yynewstate;
 }
-#line 320 "parser.y"
+#line 340 "parser.y"
 
 
 static int
@@ -1386,14 +1406,15 @@ make_string_return (char const *string, gboolean const possible_number)
 static int
 return_symbol (Symbol *sym)
 {
-	ExprTree *e = p_new (ExprTree);
+	ExprTree *e = NULL;
 	int type = STRING;
 	
-	e->ref_count = 1;
 	symbol_ref (sym);
 	
 	switch (sym->type){
 	case SYMBOL_FUNCTION:
+		e = p_new (ExprTree);
+		e->ref_count = 1;
 		e->oper = OPER_FUNCALL;
 		type = FUNCALL;
 		e->u.function.symbol = sym;
@@ -1409,6 +1430,8 @@ return_symbol (Symbol *sym)
 		v = v_new ();
 		value_copy_to (v, dv);
 		
+		e = p_new (ExprTree);
+		e->ref_count = 1;
 		e->oper = OPER_CONSTANT;
 		e->u.constant = v;
 		type = CONSTANT;
@@ -1819,6 +1842,7 @@ gnumeric_expr_parser (const char *expr, const ParsePosition *pp,
 	if (parser_error == PARSE_OK)
 		alloc_list_free ();
 	else {
+		printf ("Parser error!\n");
 		alloc_clean ();
 		*parser_result = NULL;
 	}
