@@ -5,9 +5,14 @@
 #include "pixmaps/line.xpm"
 #include "pixmaps/arrow.xpm"
 #include "pixmaps/oval.xpm"
+#ifdef GNUMERIC_TEST_ACTIVE_OBJECT
 #include "pixmaps/button.xpm"
+#include "pixmaps/checkbox.xpm"
+#endif
 #ifdef ENABLE_BONOBO
 #include "pixmaps/graphic.xpm"
 #endif
+#include "pixmaps/preview.xpm"
 
 #endif /* GNUMERIC_PIXMAPS_H */
+
