@@ -340,15 +340,17 @@ range_dump (Range const *src)
 	 * keep these as 2 print statements, because
 	 * col_name uses a static buffer
 	 */
-	printf ("%s%d",
+	fprintf (stderr, "%s%d",
 		col_name (src->start.col),
 		src->start.row + 1);
 
 	if (src->start.col != src->end.col ||
 	    src->start.row != src->end.row)
-		printf (":%s%d\n",
+		fprintf (stderr, ":%s%d\n",
 			col_name (src->end.col),
 			src->end.row + 1);
+	else
+		fputc ('\n', stderr);
 }
 
 /*
@@ -713,16 +715,74 @@ range_fragment_free (GList *fragments)
 	g_list_free (fragments);
 }
 
-void
-range_clip (Range *clipped, Range const *master,
-	    Range const *slave)
+/**
+ * range_intersection:
+ * @r: intersection range
+ * @a: range a
+ * @b: range b
+ * 
+ * This computes the intersection of two ranges; on a Venn
+ * diagram this would be A (upside down U) B.
+ * If the ranges do not intersect, false is returned an the
+ * values of r are unpredictable. 
+ *
+ * NB. totally commutative
+ *
+ * Return value: True if the ranges intersect, false otherwise
+ **/
+gboolean
+range_intersection (Range *r, Range const *a, Range const *b)
 {
-	g_return_if_fail (slave != NULL);
-	g_return_if_fail (master != NULL);
-	g_return_if_fail (clipped != NULL);
+	g_return_val_if_fail (range_overlap (a, b), FALSE);
+	
+	r->start.col = MAX (a->start.col, b->start.col);
+	r->start.row = MAX (a->start.row, b->start.row);
+	
+	r->end.col = MIN (a->end.col, b->end.col);
+	r->end.row = MIN (a->end.row, b->end.row);
 
-	*clipped = *slave;
-	g_warning ("Unimplemented");
+	return TRUE;
+}
+
+/**
+ * range_union:
+ * @a: range a
+ * @b: range b
+ * 
+ * This computes the union; on a Venn
+ * diagram this would be A U B
+ * NB. totally commutative. Also, this may
+ * include cells not in either range since
+ * it must return a Range.
+ * 
+ * Return value: the union
+ **/
+Range
+range_union (Range const *a, Range const *b)
+{
+	Range ans;
+
+	if (a->start.col < b->start.col)
+		ans.start.col = a->start.col;
+	else
+		ans.start.col = b->start.col;
+
+	if (a->end.col > b->end.col)
+		ans.end.col   = a->end.col;
+	else
+		ans.end.col   = b->end.col;
+
+	if (a->start.row < b->start.row)
+		ans.start.row = a->start.row;
+	else
+		ans.start.row = b->start.row;
+
+	if (a->end.row > b->end.row)
+		ans.end.row   = a->end.row;
+	else
+		ans.end.row   = b->end.row;
+
+	return ans;
 }
 
 gboolean
@@ -731,6 +791,29 @@ range_is_singleton (Range const *r)
 	return r->start.col == r->end.col && r->start.row == r->end.row;
 }
 
+/**
+ * range_is_infinite:
+ * @r: the range.
+ * 
+ *  This determines whether @r completely spans a sheet
+ * in either dimension ( semi-infinite )
+ * 
+ * Return value: TRUE if it is infinite else FALSE
+ **/
+gboolean
+range_is_infinite (Range const *r)
+{
+	if (r->start.col == 0 &&
+	    r->end.col   >= SHEET_MAX_COLS - 1)
+		return TRUE;
+
+	if (r->start.row == 0 &&
+	    r->end.row   >= SHEET_MAX_ROWS - 1)
+		return TRUE;
+	
+	return FALSE;
+}
+
 static void
 range_style_apply_cb (Sheet *sheet, const Range *range, gpointer user_data)
 {
