@@ -168,8 +168,13 @@ sheet_object_drop_file (GnumericSheet *gsheet, gint x, gint y, const char *fname
 		so = sheet_object_container_new (gsheet->sheet_view->sheet, pos.x, pos.y,
 						 pos.x + 100.0, pos.y + 100.0,
 						 mime_goad_id);
-		sheet_object_bonobo_load_from_file (SHEET_OBJECT_BONOBO (so), fname);
-		sheet_object_bonobo_query_size (SHEET_OBJECT_BONOBO (so));
+		if (!so) {
+			msg = g_strdup_printf ("can't create object for '%s'", mime_goad_id);
+			gnome_dialog_run_and_close (GNOME_DIALOG (gnome_error_dialog (msg)));
+		} else {
+			sheet_object_bonobo_load_from_file (SHEET_OBJECT_BONOBO (so), fname);
+			sheet_object_bonobo_query_size (SHEET_OBJECT_BONOBO (so));
+		}
 	}
 	if (msg)
 		g_free (msg);
@@ -386,9 +391,9 @@ sheet_object_create_button  (Sheet *sheet,
 }
 
 SheetObject *
-sheet_object_create_checkbox(Sheet *sheet,
-			     double x1, double y1,
-			     double x2, double y2)
+sheet_object_create_checkbox (Sheet *sheet,
+			      double x1, double y1,
+			      double x2, double y2)
 {
 	SheetObject * obj =
 	    sheet_object_widget_new (sheet, x1, y1, x2, y2,
@@ -943,7 +948,7 @@ control_point_handle_event (GnomeCanvasItem *item, GdkEvent *event, SheetObject
 		update_bbox (so);
 
 		/* Tell the object to update its co-ordinates */
-		SO_CLASS(so)->update_bounds (so);
+		SO_CLASS (so)->update_bounds (so);
 
 		break;
 	}
@@ -993,7 +998,7 @@ sheet_object_end_popup (SheetObject *so, GtkMenu *menu)
 static void
 menu_unrealize_cb (GtkMenu *menu, SheetObject *so)
 {
-	SO_CLASS(so)->end_popup (so, menu);
+	SO_CLASS (so)->end_popup (so, menu);
 }
 
 static GtkMenu *
