@@ -54,15 +54,15 @@ evalpos_hash (gconstpointer key)
 	const EvalPosition *ep = (const EvalPosition *) key;
 
 	/* FIXME: what about sheet ? */
-	return (ep->eval_col << 8) ^ ep->eval_row;
+	return (ep->eval.col << 8) ^ ep->eval.row;
 }
 
 static gint
 evalpos_compare (EvalPosition const * a, EvalPosition const * b)
 {
 	return (a->sheet == b->sheet &&
-		a->eval_row == b->eval_row &&
-		a->eval_col == b->eval_col);
+		a->eval.row == b->eval.row &&
+		a->eval.col == b->eval.col);
 }
 
 static MStyle *
@@ -71,8 +71,8 @@ sheet_style_cache_lookup (const Sheet *sheet, int col, int row)
 	EvalPosition ep;
 
 	ep.sheet    = (Sheet *)sheet;
-	ep.eval_col = col;
-	ep.eval_row = row;
+	ep.eval.col = col;
+	ep.eval.row = row;
 
 	if (!STYLE_CACHE (sheet))
 		return NULL;
@@ -118,8 +118,8 @@ sheet_style_cache_add (Sheet *sheet, int col, int row,
 
 	ep = g_new (EvalPosition, 1);
 	ep->sheet    = (Sheet *)sheet;
-	ep->eval_col = col;
-	ep->eval_row = row;
+	ep->eval.col = col;
+	ep->eval.row = row;
 	mstyle_ref (mstyle);
 
 	g_hash_table_insert (STYLE_CACHE (sheet), ep, mstyle);
@@ -307,6 +307,7 @@ sheet_style_optimize (Sheet *sheet, Range range)
 
 	g_return_if_fail (sheet != NULL);
 	g_return_if_fail (IS_SHEET (sheet));
+	g_return_if_fail (range_valid (&range));
 
 	if (STYLE_DEBUG)
 		g_warning ("Optimize (%d, %d):(%d, %d)",
@@ -1454,3 +1455,24 @@ sheet_selection_get_unique_style (Sheet *sheet, MStyleBorder **borders)
  
 	return cl.mstyle;
 }
+
+/**
+ * sheet_style_get_extent:
+ * @r: input / output range
+ * @sheet: for this sheet.
+ * 
+ *   This enlarges r by a union with each non infinite style
+ * range.
+ **/
+void
+sheet_style_get_extent (Range *r, Sheet const *sheet)
+{
+	GList   *l;
+
+	for (l = STYLE_LIST (sheet); l; l = g_list_next (l)) {
+		Range *sr = (Range *)l->data;
+
+		if (!range_is_infinite (sr))
+			*r = range_union (r, sr);
+	}
+}
