@@ -617,6 +617,19 @@ sheet_get_extent (Sheet const *sheet)
 
 	sheet_style_get_extent (&r, sheet);
 
+	/*
+	 *  Print can't handle stuff outside these walls.
+	 */
+	if (r.end.col   > sheet->cols.max_used)
+		r.end.col   = sheet->cols.max_used;
+	if (r.start.col > r.end.col)
+		r.start.col = r.end.col;
+
+	if (r.end.row   > sheet->rows.max_used)
+		r.end.row   = sheet->rows.max_used;
+	if (r.start.row > r.end.row)
+		r.start.row = r.end.row;
+
 	return r;
 }
 
@@ -1420,7 +1433,7 @@ sheet_start_editing_at_cursor (Sheet *sheet, gboolean blankp, gboolean cursorp)
 	g_return_if_fail (sheet != NULL);
 	g_return_if_fail (IS_SHEET (sheet));
 
-	application_clipboard_clear ();
+	application_clipboard_unant ();
 	
 	if (blankp)
 		gtk_entry_set_text (GTK_ENTRY (sheet->workbook->ea_input), "");
@@ -2940,6 +2953,8 @@ cellref_a1_get (CellRef *out, const char *in, int parse_col, int parse_row)
 		row = row * 10 + *in - '0';
 		in++;
 	}
+	if (row > SHEET_MAX_ROWS)
+		return FALSE;
 	row--;
 
 	if (*in) /* We havn't hit the end yet */
