@@ -10,7 +10,7 @@ void      float_get_from_range     (const char *start, const char *end, float_t
 const char *cell_name              (int col, int row);
 
 /* Various parsing routines */
-int         parse_cell_name        (const char *cell_str, int *col, int *row);
+gboolean    parse_cell_name        (const char *cell_str, int *col, int *row);
 gboolean    parse_cell_range       (Sheet *sheet, const char *range, Value **v);
 GSList     *parse_cell_name_list   (Sheet *sheet, const char *cell_name_str,
 				    int *error_flag);
@@ -28,8 +28,4 @@ gint        gnumeric_strcase_equal (gconstpointer v, gconstpointer v2);
 guint32     g_date_serial          (GDate  *date);
 GDate      *g_date_new_serial      (guint32 serial);
 
-double      random_01              (void);
-double      random_normal          (void);
-float_t     gpow10                 (int n);
-
 #endif /* GNUMERIC_UTILS_H */
