@@ -42,7 +42,7 @@ set_selection_halign (Workbook *wb, StyleHAlignFlags align)
 	Sheet  *sheet;
 
 	sheet = workbook_get_current_sheet (wb);
-	application_clipboard_clear ();
+	application_clipboard_unant ();
 
 	mstyle = mstyle_new ();
 	mstyle_set_align_h (mstyle, align);
@@ -82,7 +82,7 @@ change_selection_font (Workbook *wb, int bold, int italic)
 	Sheet  *sheet;
 
 	sheet = workbook_get_current_sheet (wb);
-	application_clipboard_clear ();
+	application_clipboard_unant ();
 
 	if (bold >= 0) {
 		mstyle = mstyle_new ();
