@@ -674,9 +674,6 @@ paste_cmd (GtkWidget *widget, Workbook *wb)
 {
 	Sheet *sheet;
 
-	/* These menu items should be insensitive when there is nothing to paste */
-	g_return_if_fail (!application_clipboard_is_empty ());
-
 	sheet = workbook_get_current_sheet (wb);
 	sheet_selection_paste (workbook_command_context_gui (wb), sheet,
 			       sheet->cursor_col, sheet->cursor_row,
@@ -923,9 +920,9 @@ workbook_edit_comment (GtkWidget *widget, Workbook *wb)
 
 	cell = sheet_cell_get (sheet, sheet->cursor_col, sheet->cursor_row);
 
-	if (!cell){
+	if (!cell) {
 		cell = sheet_cell_new (sheet, sheet->cursor_col, sheet->cursor_row);
-		cell_set_text (cell, "");
+		cell_set_value (cell, value_new_empty ());
 	}
 
 	dialog_cell_comment (wb, cell);
@@ -2171,10 +2168,9 @@ workbook_new (void)
 	/* Get the menu items that will be enabled disabled based on
 	 * workbook state.
 	 */
-	wb->menu_item_undo		= workbook_menu_edit[0].widget;
-	wb->menu_item_redo		= workbook_menu_edit[1].widget;
-	wb->menu_item_paste		= workbook_menu_edit[5].widget;
-	wb->menu_item_paste_special	= workbook_menu_edit[6].widget;
+	wb->priv->menu_item_undo	  = workbook_menu_edit[0].widget;
+	wb->priv->menu_item_redo	  = workbook_menu_edit[1].widget;
+	wb->priv->menu_item_paste_special = workbook_menu_edit[6].widget;
 #else
 	{
 		GnomeUIHandlerMenuItem *list;
@@ -2193,9 +2189,11 @@ workbook_new (void)
 	/* Disable undo/redo for now */
 	workbook_view_set_undo_redo_state (wb, FALSE, FALSE);
 
-	/* Disable paste & paste special, they will be enabled when
-	 * there is something to paste */
-	workbook_view_set_paste_state (wb, 0);
+	/*
+	 * Disable paste & paste special, they will be enabled when
+	 * there is something to paste
+	 */
+	workbook_view_set_paste_special_state (wb, FALSE);
 
  	workbook_create_toolbars (wb);
 
