@@ -3,7 +3,7 @@
  *
  * Daniel Veillard <Daniel.Veillard@w3.org>
  *
- * $Id: xml-io.h,v 1.8 1999/08/11 07:30:36 unammx Exp $
+ * $Id: xml-io.h,v 1.9 1999/12/30 06:44:47 jody Exp $
  */
 
 #ifndef GNUMERIC_XML_IO_H
@@ -13,7 +13,7 @@
 
 Sheet    *gnumeric_xml_read_sheet     (const char *filename);
 int       gnumeric_xml_write_sheet    (Sheet *sheet, const char *filename);
-gboolean  gnumeric_xml_read_workbook  (Workbook *wb, const char *filename);
+char     *gnumeric_xml_read_workbook  (Workbook *wb, const char *filename);
 int       gnumeric_xml_write_workbook (Workbook *wb, const char *filename);
 
 void      xml_init (void);
